<style>
    .inline {
        display: inline-block;
        vertical-align: middle;
    }

    .header {
        background: #21264a;
        padding: 5px;
    }

    .header h1 {
        margin: 0;
        color: white;
    }
</style>

<div class="header">
    <img src="{{ url_base }}/static/images/logo.png" height="45px" alt="" class="inline" style="margin-right: 5px;"/>
    <h1 class="inline">D-Genies</h1>
</div>
<h3>
    {% if status == "success" %}
        Your job {{ job_name }} was completed successfully!
    {% elif status == "no-match" %}
        Your job {{ job_name }} was completed.
    {% else %}
        Your job {{ job_name }} has failed.
    {% endif %}
</h3>
<p>Hi,</p>
{% if status == "success" %}
    <p>Your job {{ job_name }} is done.
        You can <a href="{{ url_base }}/result/{{ job_name }}">click here</a> to see results.</p>
{% elif status == "no-match" %}
    <p>Sorry, we did not find any match between your query and your target.</p>
{% else %}
    {% if error != "" %}
        <p>{{ error | replace("#ID#",job_name) }}</p>
    {% else %}
        <p>Your job {{ job_name }} has failed. You can try again.<br/>
            If the problem persists, please contact the support.</p>
    {% endif %}
{% endif %}

{% if target_name != "" %}
    <p>Sequences compared in this analysis:</p>
    <p><em>Target:</em> {{ target_name }}
    {% if query_name != "" %}
        <br/><em>Query:</em> {{ query_name }}
    {% endif %}
    </p>
{% endif %}

{% if status == "success" %}
    {% if target_filtered %}
        <p>Note: target fasta has been filtered because it contains too small contigs.<br/>
            To see which contigs has been removed from the analysis,
            <a href="{{ url_base }}/filter-out/{{ job_name }}/target">click here</a>.</p>
    {% endif %}
    {% if query_filtered %}
        <p>Note: query fasta has been filtered because it contains too small contigs.<br/>
            To see which contigs has been removed from the analysis,
            <a href="{{ url_base }}/filter-out/{{ job_name }}/query">click here</a>.</p>
    {% endif %}
{% endif %}

<p>See you soon on D-Genies,</p>
<p>The D-Genies team</p>