<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>D-GENIES - Dotplot large Genomes in an Interactive, Efficient and Simple way</title>
    <script type="text/javascript">
        {{ js | safe }}
        d3.boxplot.events.context_menu = {
            actions: [{
                name: 'Export SVG',
                onClick: dgenies.result.export.export_svg
            },{
                name: 'Export PNG',
                onClick: dgenies.result.export.export_png
            }]
        };
        d3.boxplot.help_zoom = "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMgAAABUCAYAAADH/HimAAAABmJLR0QA/wD/AP+gvaeTAAAACXBI WXMAAA7DAAAOwwHHb6hkAAAAB3RJTUUH4gcQCS0wfEPKagAAD41JREFUeNrtnXtwVFWexz/35EEi b5THBiNIIo/dDaOLCFK8lFCAMBsHEdglaAGuiA5bK46lYFFZtZyMBVMzpYOoiC8YwqBEXNhSwOwK swo4ZEJAA8NLHopDyLJC59HppH9n/+gHTZNHd9Kdvh3Op+rW7dzue87Nued7f+d3zu+cCwaDwWAw GAwGg8FgMBhsgWWKwBAKIoJSKvBvBXQFbgJSATdwCbgAuJRSurFzjUAM7UYUgL9yi8jtwGSgH9AX 6N6IQC4Bx4GjSql3TUka2q04vJ/7i8ifRMQhInXiQTez1YuIU0T+KiL5wekGpm8wxJ0wRMQSkV4i sjUEMYSyfS8iuSKS0pAIDYZ4shiJIvJIhIQRvBWJSKYpcUM8isTy7t/zNqV0lLazIjIpHqyIcdIN V/UyicgeYGQbZT1JKbXDzr1cRiBGHIHi2Alkt/ElDFJKHQ3uMbMLiaaKXN8opXxNq18AE8I49Thw BrgI1AEKuAFP9+8teLp/Q+EvIpKmlPrBOO0GW1oQEfmpiFSH6D/8UUSmicgQEekSlFaSiNwsIiNF 5IkwfJLfmzthsKs4UkVkR4jjGv8oIjeE6vCLSGcR+TxEkUw3d8RgK3F496NCqLznRGRY4Hlh5pEX Qh4HRaSbuTMGuwnlRDMVt0JEhocrjqA8OorI2yGIZIy5IwY7WY+cJiqrL5xkaivF4dsni8hnzQhk U2vyMhgiLZR3m6mwbwVX9FaKZERzVsTcFYNdxJEsIj80UVndInJLFKzW3mZEMsdO5aRMVQmfurq6 9vBvdANSmvh+F1ARqeZOwADgz5v56Vw7NbPabKCwtraWDh06AKC15ttvv0Xr+LGoWmsyMjKwLIuk pCTOnTtHWlpaPAvkb4CEJr7fi2fiU6R9n78AP3jzb4j+QYKKKREJNdm5cyfZ2dnk5eWhtaaiooLp 06cDWNnZ2UPy8vIWaq3/taKiIu5qUffu3enUqdO6pUuXvr5r1649gB43bhyWZbFnzx7uvvvueG1i 5QJrmrAi/6yUKohCvjcAfwCmNfKTU3jCT1ztRiBaa/Ly8jhy5AgTJkzg1ltvZeLEiQA35eXlXQg8 Hm+cOXOGnTt3kp6ezooVK24Gvl+0aBGPP/44Q4cOjWcf5CkgH0hq5CcPKKUKI2E1AmK9kvFM030T uL+RU8qBKcA5oBKoUUq5g9OKK4E8/PDDaK1Zs2YNtbW1ACxevBjgE6315MDj8UhKSgoLFy4EOAQM vfHGG7l8+TJvvvkmANu3b2fSpEnxJpClwAtNNLN/ppTaEkFhTAYmAWOBvw8lCWA3sAPYoZQqjoVI IuKDaK156KGHrhKB17+YHHw8HnE6nTz22GM899xzWRcuXDh54MCBicCJ0tJS9u7di2WZoOgGfA3f 51HAr4BRzfg8DXUgjfduS0TkHeBVpdRZEbECF4WIJhGRYkVFBYMGDbrmWEPH45W0tDS01pSWlt46 d+7ctXPnzqWkpISZM2cCsH79eqOMgCe8N0p4O7ATGBOmOIK5CU+08Z9F5OdKKe2NI4sfCxJs9nw9 VPG63EtTrF+/fpzD4RiwevXqk126dEFrbaxIgDhEpB+wLcSmVDjuwE3AqyJyI/BLpVRdtJtctpwP opS6qsJprf1bVBwxy8KyrLDy2LNnzyRgdbdu3di9e7cRxxVx3AmsAwZHMbt/xzPnZIE3z6iJxHaP d601+fn5jB8/nr59+zJ8+HBmzJjB5s2bSU5OjkqeBw8eJD8/n61bt4Zd0CKCy+UK6/8LFqL374Fa 63/x7uNVHD2Bj6MsDh/zReQN3wM1WmVmGwvicrmYNGkSxcXFVx3/8ccfKSsr49NPP2XevHlUVVVR X18f0bxLSkp46aWXeOCBB8jJyYlVEWwDbgOOAQPjTRxevgTCGj31thR+BDpoSCW8iv6oiBxWSv02 WgKxhQU5cuQI/fr1o7i4mPT0dNatW8f58+fRWlNZWcm+fftYvnw5PXv2vOZJkZiYSGJi63Tua87F 2F+6LWgfFwR05b4BZIRR6OB2H/5qwYL/3GBZ3f5gWfrC558XWJblDPMS8kVkaLttYrlcLu69916q qqq44447OHbsGDk5OaSmpuJwOBARhgwZwjPPPMN3332H2+2+ShyrVq3ixRdfpKqqynQhxc6KZOEZ GQ+5p8KCmt1Tp17+/uOPp3a++Wad2rfvDbunTHnw5Ftv/T7MDo8UYHWoMx3jSiCWZZGTk0NlZSW9 e/fmyy+/bLQ9LyI4nVc/XJKSkli9ejX5+flUVlaamhobcSQDj4XVtLIspK7u0KVDh+5MSElBi1ho TXKPHonHfve7XG8zMxyGA1Oj0e0bU4G43W6++OILAFauXBm1KFlfv3xDzSpD6/wPPAtXP96Cp+P/ WQkJrmCfw1LKAVwOM7Uk4PZo+NQxc9Ity2LlypUAdOnShdzcXBwOR0jnJicns2TJEqqqqigvLwfg 2WefJSUlBa01gwcP5sknn0Rrzfnz53nwwQfp06cPhYWFVFdX88ILL1BcXMymTZvo3Lmzqemt67la FtGEW+5sLwNeBf7abgSyYcMGAO66666wwlESEhLYunUr5eXl/vO2bt2KZVmICGPGjGHJkiVoramt reXAgQP06tWLbdu2MXv2bP8IbKA/Y2iZc+5t3tiFycC77aKJJSL+p3/Pnj3DqqzV1dWcOXMGp9Pp Hxs5ffo0TqcTl8vFjh07rglDqKmpYdasWaSlpbFx40acTifdu3ePu4qZkJBgm2sRkSTgHhsVz5MB Tb/4FohSiqSkJH/lDccnsCwLh8OB2+32d/tWVlbicDhwOBxUV1dfc47D4SAzM5OTJ09y33334XK5 iLcBOZ/Vmz17tl0u5yc2K55bRSQpkl2+MROI1pqsrCwAjh8/7hdLNNm0adM1PWGR/H8a2QZqrY9q L4B/a+AYwd81REFBwVGbjLjbTSAd8c5IjHuBACxduhSAr7/+mkuXLkU9vxhNkR1HaIN/VtC+KW7z phtrhtjNNcIz1759WJDs7Gy/H7Bo0aKod722dsS9hewitH59HbRvimPedGONHZ041S4E4vM9nnrq KQA++OADjh8/3qRIGvrOLuMZvojgBrajlmUNtLx4LYTlOeWaYwR/1wgDvenG/N9uzTPShtdkL4EA LFmyhNzcXACGDRvG7t27G+ypSUxMpKioiMLCQr8otNZ07doV4KpQEzv19Bia8BcaUnhCgoVn8LH9 maOWUF9fz2uvvcby5csREaZOncqQIUNYvHgxr7/+Oi+//DIzZ84kIyOD+++/n7KyMn+5ut1uxozx LOc6Z84c3njjDXJzc+nfv79ZvtLmqMTEEZ0HDvyT+Ma/tKb2woVDt8yadQ74W7tcp23C3ZctW8bk yZNZsWIFW7Zs4b333rvq+/T0dPLz83n00Uf9lb+uro68vDwKCwv55ptvePrpp7EsiwULFgSO9Dab t2+w0QQ8tpkDCpaVPP6zz7rsmzv319999NFIKynp+Ljt21N63XPPBC3iifY1ArlCXV0dWVlZbNy4 keTkZI4ePcrp06fp1KkTgwcPpkePHlRWVl4z0WjAgAGUl5dTWlpKeno6gwYNoqamxj9nZMCAAf5z GgtleeKJJ/yhKSbose06aYCfjFi3rv+wysoOVlLSUNWhQ6rWOhEbxcnZbsqty+XC5XKRlpZ2Vbds Y5Vba01KSgojRoxo8Hci0myMV21tre1WXpk+fTqFhYXXg1C6JnTsCJCCDQduzdq8NuWdd96JSroB Tc7eNL7SiAbqzV0wArEtvt65iN/wK2EY6TTeJVrt3YxATBHYhmNB+6ghIoOBptZNPe/drnsi4oMo pa5ZSMH3pIr0AgsxdiqjyTQ84SO7oigMvFZjIpDZxE8PKaW+MfKIkAXp06cPpaWl1xxr6Hi8cvLk yYiIJ3CUPejYUcuy1kRjhFxrjdPp9D207gaWN/FzN/DnIH/FCKQ1ZGZmsnbtWtxut//GZ2ZmkpmZ uX/t2rU68Hi84bvuVatW+eevgGdWY3JyMpZl2XpeiYhgWRYpKSmIyM+AD4GeTZxSBfxHkL9y3RKx Wpufn09RURFjx471O5jeeRlVRUVFqWPHjrWi5XhGE4fDQUlJCadPn2b//v0AdO7cmcuXL/cDzvTo 0YOLFy/a4gHQ2AqDInIz8BowAWhu9Y9ipdSdIeb3NjDPZrfsbqXUXlv5ICdOnCAjI4Nt27axefNm ysrKfNNprcOHD3fMysravHnz5l5lZWWjfU+0ePE7RISzZ89eZT3ef//9/9qyZcuZmTNn8sorr2BZ FpcuXSJWD4AAYSSKyD94fYzeQBc801B7h5HcZON5RFggGRme9cKmTZvmF8zo0aOprq72zgfigZKS EoBPRo8ePbq6urpTvM3m69q1K6mpqe5169adAiY88sgjPP/88yxatIg5c+YQS+sYYDV+BTzViqT+ SSlVEYsX1bT7JlYwX331FQUFBdTU1PiPzZ8/HyChoKBABR6PiydJYiLTpk3TQP3+/fuZMmUKw4YN A+DDDz9kxowZMbUeIjIPeLsVSa3Fs75VfajiuB6aWDFj7969GCImEiUiG5t7B3kT2wbvAgxh9VyJ yNutyDNa20jbNbFawsiRI03NjmAri8bfNdgULm+v1vy2eNdGW7mOkS5YQ3xbD5RS9UBJmKceBx5S Ss1RStW2UBw17V0giaaKxbnpuFKpfwPcBfy0mVM+xvNyzEKl1KlAP6YFnLJhkTiNQAwNWZEqEZkB /BvwS65E6mpgH553k38AXARqlVLSgMjCxW7hKLV4Xh8dMcwKzu1PKG2ZXw/gf21UBBeUUr0iWQ7G B2mfza22yu8iEV4supV8FOlyMAIxtJbPbHQtv4n4Q8DcX0NLm3Ne3rXJJf0ROBvpCGQjEEOLm3Pe yrjPJs76h0B1pJuZRiCGVolEKVUJ/ILorZQYCqeAT5RSEb8GIxBDJPgfoChGebuBlUqpqExVNt28 hkj5JKOAz2lZyEtr2K+UGu7ziyLdxDICMUTEYff6JA8Cm9ow6zqgq1Kqxu12R2VNZtPEMkTKYbeU Uh8AeXhGtKNNOfB3SqkaETELlhvsb0V8XawislBEXFEMaT8tInf48jUY4kYkAZ+niEhNBEUh3v1u EelmStvQXoRyUEScrRSHW0TqvcGYtKXlME66IaqOu/dzDjAbuB0YHGZS/w0cBH6tlDrb1gGZRiCG thRNJjAKz+J1vtVWkrkSml+PZ03gw8A2736HUsoRq2s2AjG0mSUJOJaM5zVrCs8idh3xDPhdBi7h 6b6tUUq5m0rHYLhufJW29i0MBoPBYDAYDDHj/wFpQxVXb3nKVAAAAABJRU5ErkJggg==";

        d3.boxplot.help_trans = "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMgAAABUCAYAAADH/HimAAAABmJLR0QA/wD/AP+gvaeTAAAACXBI WXMAAA7DAAAOwwHHb6hkAAAAB3RJTUUH4gcQCSs6ysyE8gAADWxJREFUeNrtnXtwVFWexz/35EEC CQhrlG0nw/sRh8g6FrJTBUghDNRKTRgFzKxBh3VFLcrZNawlYYrKCKspCpip2RpQdNCSUEBh0cIm PkZka8OWsCoRopBFXmOIwywRdySddDqd9O/sH+kOCUk63Z3u5HbnfKpudSf3cW7fc77nd37n/O45 YDAYDAaDwWAwGAwGg8EWWOYRGEJFa41lWR3/VlrrUUAa4ANcSqmGwH4RQSllHpxhcCAi6SLyQxHZ LiLNIqJ72E6IyD+IyHARsQJiMRgSVRjDROSCiHiCiKKn7f9EZI0RiSGRBBHYhojIZxGIorvtWxFZ Z4RiiHtx+D9/7i/YEiWBBLZPRSTVOOmGeBWHBbwK/GOMk5umlDpjBGKIG3EopRCRE8A9/ZTsA0qp d+3c22UEYmjvvhWRd4C/6+fkxyqlauz6bJJN8TBorRGR30Ygjo+Az4B6IAVwAHlAZhjXOA+kmjET g52bVxNFxBeik10lIr/o5Xo/EJHfh+G4V5lcMNjVKSdEcbSIyPKAxQkjjT+GKJLZJkcMdhTJwhAK ryfcEfGAiETEEpHyUNIwuWGwo0BCsR5DIx3c62CltoeQzs9NjhjsJI77Qyi08wLWIwpNuU97Sett kysGOwnkV/1VYP2hK1N7E6TJFYOdBOLupcDmRDtuSkRO95LmT+30jEzH8+AmPWjhUOp/YjA2saCX /cuNQAx2sB6393LIb2OQJsC3QFOQw7Lt9JxiOpJ++PBha/78+TnFxcVPaq1/ce3atbgrSCNHjiQj I6O0qKjolYqKiuPHjh3TRUVFVFRUMHfu3HjWyMxgOy3LejHqtbFSaK1bAXdH63XTuMqtdnpIMY3F 0lrfWlxc/M3Zs2e5//77GTduXNyVosuXL3P48GGys7PZvHnz9/Lz8//k/97p9dM4tCBPA9uDHDJC KVUf7XT//fvf/9u/2br1/RaXa0TzN9/Qcv06uRs3wo1nWQf8GHArpc4HLM9AhaHENIcfe+yx97TW i1577TWam5vjtjClpaXx5JNPAnyxY8eOu/zfeeONN+JZIP8M/CbIIcOVUq6+pHHI4SDvyhUOORwp wAZgbZdK1Odj5p49jJ43r6cR+n8Btg6UQGKaqtZ60aOPPhrX4gDweDw89dRT1NbW5s6YMePS66+/ PqG2tpbp06eHFXYx2PCLoxrwdicOf1sO7fUGu8wWoEVE/quDH5MYPsi1a9eYMmVKQmS2w+FAa01V VdW4FStW7NRaz62qqmLFihVGCV0thwXkAi8AOb0d7+u9Ak0GZolIPfAz4J2EEIjWOiFDmHfv3n2f y+Uan5mZeWn37t24XC4yMzONMm6IIwcIOUJXQm9hZALlIvKSUuqX/eGb2LL0KqVISkpq35RSMXWI LcsKO43jx48v7PDdKOOGOP4KCOtVWl9TU7hJrRORCv8bkINLIFprSkpKmDt3LnfccQczZsxg6dKl HDhwgNTU2Lzr//nnn1NSUkJZWdmAWTyt9WSt9RNa68lxKo5Aefom3HMjEAjAHBE5EOv8ss0bhV6v l4ULF1JZWdnp/9999x3V1dW8//77rFy5ksbGRlpbW6Oa9smTJ3nxxRd56KGHyMvLG6hHUA5Mou0N u3gUyTTgi0hO9LndAE1a6/QwWwoPishPlVIxC3K0hQU5e/YsY8aMobKykuzsbEpLS7l69Spaaxoa Gvj4449Zv349WVlZXXqNkpOTSU7um84DmTLA/tKkwGd+fn489o79a7gnDLUsXnW5yF+zpsKyrHSn 0/nrCH63U0QmxaqpNeAC8Xq9zJs3j8bGRu6++27Onz9PXl4e6enpuFwuRIScnByef/55vv76a3w+ XydxbNu2jY0bN9LY2Jgwbfl33303bgYhDzkc1iGHYwPwk7CaLpbFpr/8hfcaGzkF9wEsW7assKKi YnsEt/FmrCq3ARWIZVnk5eXR0NDA7bffzrFjx/D20CcuIng8nV86S0lJ4eWXX6akpISGhoaEEUh2 dnbc3GvelSsaWE+Yg87plsWHbjc324tVq1bNj+A2fiQicxJOID6fj48++giALVu20NLSEptaQKku zad4DhOxmQU5FM3rNTc3eyM89XcJ5aRblsWWLVsAGD58OAUFBbhcoUU2pKamUlhYSGNjI3V1dQCs XbuWtLQ0tNZMnTqVZ599Fq01V69eZdmyZYwePRqn04nb7WbDhg1UVlayf/9+M37Rd+ZFu1xESK6I pCilWhJGIHv27AHg3nvvDSscJSkpibKyMurq6trPKysrC0x+xuzZsyksLERrTXNzM6dOneK2226j vLyc/Pz89r7zjv6MIWIybHQvjwI7E6KJJSLttX9WVlZYhdXtdnP58mU8Hk/72EhNTQ0ejwev18sH H3zQZQCpqamJhx9+GIfDwb59+/B4PIwcOdIU7741r35gs1valDBNLKUUKSkp7YU3HNNqWRYul4uh Q4e2d4c2NDQEbaK5XC4mTZrEmTNn2oU0kIwdOzbob+5uf8cmpU342GYCGSUiaUopT9wLRGtNbm4u R48e5cKFC6SkpER9APBm9u/f36UnrB9+52RuDAIGPdTfE6RPnz7d22DAeWCxZVnnjB3rwgggapk8 oL1YRUVFAJw+fZrr16/HPD1HWzhEf3NfCOKAG92koZjSSf7rGro+wyEJ4YNorZk/f367H/D000/H vOu1ryPuEVLhr/F7fSQ3ffZmQSqMHoJWNPFvQZqamlizZg0Ab731FhcuXAgqku722X08w7Ksc5Zl TbZ6oaMFmTZtWm+HT07U5lUUQmwSRyAAhYWFFBQUAHDPPfdw9OhRkpKSuq39jxw5gtPpbBeF1poR I0a0O7ABujvfEB8MGTLEVsuzDbhAWltb2b59O+vXr0dEeOCBB8jJyeGZZ57hlVdeYdOmTSxfvpwJ EyawZMkSqqur2wXi8/mYPbttUvBHHnmEHTt2UFBQwNixY81CkTbHLcJPhg3rUt2//fbbe+10n7YJ d1+3bh2LFi1i8+bNHDx4kDfffLPT/uzsbEpKSli1alV74W9paaG4uBin08mZM2d47rnnsCyLxx9/ vOOSYr2mHRhsTKSAR7vjA1bfcgvDk5LYXV8PsNvpdP7pzjvvLDYC6YaWlhZyc3PZt28fqampnDt3 jpqaGjIyMpg6dSqjRo2ioaGhUxtVa8348eOpq6ujqqqK7OxspkyZQlNTU3uX8fjx49vP6WmcZPXq 1e2hKXYIeox1d7dd8GjNsowMVg4bxrwrVwrsGOJvuyXYvF4vXq8Xh8PRqVu2p8KttSYtLY2ZM2d2 e5yI9Brj1dzcbKuZV7788sv2dQMHAy4bN4fNGoU2pR/EcUeQfSFV5drnU7qnwt2TNejm/9rGMXFG IIOXHwbZJ/4tKHP+8IdDQ7Ky8m8Ws9aapCHdj9dZ/vCi7loCRiCGYJznxjvpMaPDVDl3BWvp+v3o oNxy112uRM+UmApEKZUwDmc/1HCLaQsfqYh1nvinHQ02SbQbaMYQ23GQ0aNHU1WVGCv8Xrp0KdY+ xznLsl6L1Qh5h2XQRgFbezm8RCll5lSNtUAmTpx4YufOndrn88Vtj0zgvrdt29Yp1LzjHF2xmq8r BpZjMvDn3vJdKbXVSMOf/7FOoKSkpPHIkSPpc+bMsQJhIfGEy+Xi5MmT1NTUcOLECQAyMzOpr68f Y1nWZf93W1QAAStx8/v3IjIG+CXwRAiXOaSUWhJieq+GeM3+ZJxS6qu48EEuXrxoTZgwYVh5efmB AwcO3FZdXT1LROLGmmitERFqa2s7WY9du3b9h2VZl/3fbSMOv5VYIiL3AVm0LVIz2/89VFYau9GP FuQmwbw3a9asWW63OyPeJkazLIv09HRfaWnpV0uXLp2Ynp5OaWkpCxYssM09isjLwFN9uMQTSqnf h5FewluQfq/6Pvnkk6S9e/eqpsjmYx0wkpOTWbx4sT548GCr/zuLFi3C6XTy4IMP2qFpNRP47z5c 5rBS6sfhzJhuBGKIG0Tkd8DqCE//UCm1INzlBAaDQMwqt4lDpD0g/xaJOAYL5okkDuHOB/UtsEQp 9U8Q8cTddmwnayMQQ9eMVOo/CW30ux54QSl1K9DXaUP/aMNH0WoEYuiJocBL3fz/JLCOtvCSkUqp X0WpSXXKhtYjqi/0GCc9sRz1fvUjREQRQlBjP1vSxJq0wRDVwtHf6QkRLLkWQ3YZJ91gN76w0b1s NAIx2KfB3xYN8Wub3M5VpdQFIxCDbfAvn/0O8JUNbudYLKZ6Mk66IRrO+s+APQN4C26l1LCY+Fkm ew1RcNb3AgM5FeramFlJk72GKFgQgO8BtQOQ/Dml1BQjEEM8CGUG8Ek/JzvM38SKjXU02WqIlhVR Sn1K24h9f/HXSil3LMd/jEAM0fJDAiIpoW8vbYXklAMTlFL/G+vfZZpYhlhZlB8BH9IWHxZNPldK Te+vsBpjQQyx4ri/6/Ui0QlB9wB/r5SaHrBYBkOiWJNUEflMRHSE2wsikh7wdQyGhHPg/Z8jROQh EdklIq1BBHFRRF7yz87CQArD+CCGfhVKN3N2jQdG0hY2/2el1FXzpAwGg8FgMBgMBsNg5f8BHf3b UWfihaAAAAAASUVORK5CYII=";
    </script>
    <style>
        {{ css | safe }}
        body {
            padding-top: 0 !important;
        }
        img.logo-stick, form#select-zone {
            display: inline-block;
        }
        img.logo-stick {
            margin-left: 40px;
        }
        footer hr {
            margin-top: 5px;
        }
        #restore-all {
            background-image: url('data:image/svg+xml;utf8,<svg xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:cc="http://creativecommons.org/ns#" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:svg="http://www.w3.org/2000/svg" xmlns="http://www.w3.org/2000/svg" xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" version="1.1" id="Capa_1" x="0px" y="0px" viewBox="0 0 14.155 14.155" style="enable-background:new 0 0 14.155 14.155;" xml:space="preserve" width="512px" height="512px" inkscape:version="0.91 r13725" sodipodi:docname="reset.svg"><metadata id="metadata41"><rdf:RDF><cc:Work rdf:about=""><dc:format>image/svg+xml</dc:format><dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage" /></cc:Work></rdf:RDF></metadata><defs id="defs39" /><sodipodi:namedview pagecolor="#ffffff" bordercolor="#666666" borderopacity="1" objecttolerance="10" gridtolerance="10" guidetolerance="10" inkscape:pageopacity="0" inkscape:pageshadow="2" inkscape:window-width="1862" inkscape:window-height="1051" id="namedview37" showgrid="false" inkscape:zoom="0.4609375" inkscape:cx="-174.64407" inkscape:cy="256" inkscape:window-x="58" inkscape:window-y="0" inkscape:window-maximized="1" inkscape:current-layer="g3" /><g id="g3"><path d="M12.083,1.887c-0.795-0.794-1.73-1.359-2.727-1.697v2.135c0.48,0.239,0.935,0.55,1.334,0.95 c1.993,1.994,1.993,5.236,0,7.229c-1.993,1.99-5.233,1.99-7.229,0c-1.991-1.995-1.991-5.235,0-7.229 C3.466,3.269,3.482,3.259,3.489,3.25h0.002l1.181,1.179L4.665,0.685L0.923,0.68l1.176,1.176C2.092,1.868,2.081,1.88,2.072,1.887 c-2.763,2.762-2.763,7.243,0,10.005c2.767,2.765,7.245,2.765,10.011,0C14.844,9.13,14.847,4.649,12.083,1.887z" fill="#388700" id="path5" style="fill:#000000;fill-opacity:1" /></g><g id="g7" /><g id="g9" /><g id="g11" /><g id="g13" /><g id="g15" /><g id="g17" /><g id="g19" /><g id="g21" /><g id="g23" /><g id="g25" /><g id="g27" /><g id="g29" /><g id="g31" /><g id="g33" /><g id="g35" /></svg>');
        }
        #restore-all:hover {
            background-image: url('data:image/svg+xml;utf8,<svg xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:cc="http://creativecommons.org/ns#" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:svg="http://www.w3.org/2000/svg" xmlns="http://www.w3.org/2000/svg" xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" version="1.1" id="Capa_1" x="0px" y="0px" viewBox="0 0 14.155 14.155" style="enable-background:new 0 0 14.155 14.155;" xml:space="preserve" width="512px" height="512px" inkscape:version="0.91 r13725" sodipodi:docname="reset_hover.svg"><metadata id="metadata41"><rdf:RDF><cc:Work rdf:about=""><dc:format>image/svg+xml</dc:format><dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage" /><dc:title /></cc:Work></rdf:RDF></metadata><defs id="defs39" /><sodipodi:namedview pagecolor="#ffffff" bordercolor="#666666" borderopacity="1" objecttolerance="10" gridtolerance="10" guidetolerance="10" inkscape:pageopacity="0" inkscape:pageshadow="2" inkscape:window-width="1862" inkscape:window-height="1051" id="namedview37" showgrid="false" inkscape:zoom="0.4609375" inkscape:cx="-58.636054" inkscape:cy="256" inkscape:window-x="58" inkscape:window-y="0" inkscape:window-maximized="1" inkscape:current-layer="g3" /><g id="g3"><path d="M12.083,1.887c-0.795-0.794-1.73-1.359-2.727-1.697v2.135c0.48,0.239,0.935,0.55,1.334,0.95 c1.993,1.994,1.993,5.236,0,7.229c-1.993,1.99-5.233,1.99-7.229,0c-1.991-1.995-1.991-5.235,0-7.229 C3.466,3.269,3.482,3.259,3.489,3.25h0.002l1.181,1.179L4.665,0.685L0.923,0.68l1.176,1.176C2.092,1.868,2.081,1.88,2.072,1.887 c-2.763,2.762-2.763,7.243,0,10.005c2.767,2.765,7.245,2.765,10.011,0C14.844,9.13,14.847,4.649,12.083,1.887z" fill="#388700" id="path5" style="fill:#ffffff;fill-opacity:1" /></g><g id="g7" /><g id="g9" /><g id="g11" /><g id="g13" /><g id="g15" /><g id="g17" /><g id="g19" /><g id="g21" /><g id="g23" /><g id="g25" /><g id="g27" /><g id="g29" /><g id="g31" /><g id="g33" /><g id="g35" /></svg>');
        }
        .chosen-container-single .chosen-single abbr, .chosen-container-single .chosen-single div b, .chosen-container-single .chosen-search input[type="text"], .chosen-container-multi .chosen-choices li.search-choice .search-choice-close, .chosen-rtl .chosen-search input[type="text"] {
            background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAADQAAAAlCAQAAACn+wJeAAAB4UlEQVRIx+2XsWtTURTGrwouLQQD wYLFzT3yJBDoYoVvySQoKFShSHe7qAgqiMn9rcUibnVwEARBl0AgUIh/QXBxFIpKJHAhUBz0HQcf 4U0xtZwu+r3l8t4758fHPe/jvhBcRIUuWbFuMKAWnEB9jEQWAk0SRt8LtMo+RmKdhDGiHrzEChOM HGPsiAkhBDbIMXKu+2KaJUfZwcsXD4RJrJFKKHaw6fVmRnmNT5ydC9TDSDRCIGOMMfh9u8pegRmz NKP8NUZvzu+oR6NY19mddqVVgG7MKL5SvHPrcJu3g/F2xvMqowKUOHMYUJXhrAa8Ku1j90/dVFFX xaypoYFqfzFR80h9mZKyENRUkskrgrSqfZmS1pVkGskvG7SiiUy5TGP5RpA2lMuUyzeC1Cw5yrwx SWtKrij1ZEpqhKBMY5kGXqCKeioiSHXtain817+k9gLLLD887ozhLl8xjGG86onZxuIe99jCsHjT CRMvYvF9+1QIIcTz8RuTzmkfP0+jdaYJHW9jXPYBvYj5/ZNlf06HxvgEYzoC8Tk5l1xAnXP8IHVa m8faC3GTn3x5cMJr6q5h0fjI5+L4suU24PFCfMkHhvExHQyL20eQEfERhsVncdEfdYfvGK2jcPUO K/+A/QJb5yp50uoC6QAAAABJRU5ErkJggg==');
        }
        .ui-icon,.ui-widget-content .ui-icon, .ui-widget-header .ui-icon {
            background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAQAAAADwCAQAAABFnnJAAAAAAmJLR0QAIn/tYtYAAAAJcEhZcwAA AEgAAABIAEbJaz4AABonSURBVHja7Z17aGXHfcc/Z70br7y2e5W0MRIp3gep+6DsXUsmcXHxVds0 awdiaUuaUihItpEaQu3EUChJwXZK6F+x3QTTrklW20ACbkKkNWmyTh+SsWkTR/JqcesmDX5BI1Ga 9qruH3JYJ6d/nNfMOfM659yre6Uz30V77z2/ec9vfjNnfr/5TXAcjybjwKAL4DFYeAZoODwDyBgj ZGzQhdhNeAYQMcYmsNkkFug1Awx+/IwRVo65CYyjY4Ek5cHXsYeQGcAsAMP0nwm28aOPH8a5j2nD 2PJOOrFaDaLu34pZwJTyPpIRIgP0QgCO10ghiZuMw/KoExcCAraALQICQ8p16jh0CNJ9gKSKyTjQ IYRC84iI0gkqxU9GmS5/W95hzbK7pmyr4x5CJgHMAtAVpjFonz6i3E1daE6l3tg0TUFiyvXkzJAh KL0TaB5FpjGYNWrVsWNPwTw2zWU3y8AsZZuc2VMozwBmhANvmjE2KzOYeQpKUh58HXuIXjPAXscY m/upe+04OOgCDBm29sfSzh1+J7Dh8AzQcHgGaDg8AzQcngEaDs8ADYdngIbD2wPk4w66/LuMMvYA bhYBNmXMmNEewJyDvXvq2APY1eFR2fcVk5SzB3DTgJmbUN9B45rvrmnbut+W+mbuU5/6vrEGKNoD RNDvhiehTPo2Pd0W28UewFQ6c+72+GaEcdrJ576AbA+g+i5jy0kKqMPYx6eLPYBp/LmVTc8+odXa oExOewJVtIEmheuw2wOYmMsmf5Kae3WwAYNvnLr2AIMu/y7D2wM0HH4jqOHwDNBweAZoODwDNBye ARoOzwANh2eAhsObhecRDnCXv/5eaenyH6wXvS+NMMgShNYSVFcF2WMOoObyFBCCUdfv4h8grEAp i6p52MofdX1gTMXOHFVju9XAJVSJuAekALbqBw4V0McPHBrIpQqhQdnjUr7AQJM/y+WRUOwtYK6h mYFCS2ywDWKp/OIU4Fp9nbWOvZGCHgj40KiJtM2idUoQprEDJVXMXZVLMrz0ZQgNdHPaWe3Mw0As ZQBlF4Ghw+ixhXLhzmpj3K1zA4fUTR3kkm7VFjANQZe07W1QoJd5DcxEnEsoNc0sAu0cbE7DJmLd RLRtBNlyd1lEVoWdxe10qQRlJICb6Ky3yg0cpUy/yhgYBaxbuoFDmKowT9PmCVAZ96Am0OAw6BLs 5fwrxPU7gQ2HZ4CGwzNAw+EZoOHwDNBweAZoODwDNBzy4dDEWergYPcH3k+4tICLRrRaPNvZaNdc SiFjgORglIu792oN0DtUS8tWcrcWMLmazbRxY6VjR3rK5J++DmOVWyDMlRJQHw41H+F00WiPKZ71 jgV0abm5htCX360FdHmM5Y7XjpWKndXAJoHqHU0vHNCVj4a5uFO3HcHWHRB1s6Sxl0CXjt2Fu73k bg7p1RqDYtcGObrtYHnWOarziaGUsllhrFNYB8UwZRnAvQGCEnHdSmBuQpf87Wf79fnbYtsYwN4G 5g60M4CZgTQMUO4tIGuAKiqLQEhDnXoofZryr4Ks3FXXEKbcx2NqMoOrPQiY8k9iqtcAtpQz3w2m 8835Upa0BzA1gLyAMVXfXDhTFU1piFWzm32pusDOgKYabOUcSGyVTsENpu7dSq+9cSslZacAN3Oq 0OoiwjwL1ont1rzqerjNwfVN2kzpVL/Uxr4GUML7BxAxZr0xad/BHwwR0bjbAvxWcOPhGaDh8AzQ cHgGaDg8AzQcngF6jUGqsysgbw9gg0lf5VL1sZr67n6jfukCy2b3kNW9aA9ggklj7rJLmGjsxh0O mOpR93CV+Xh4YD3+au9gXXxT6gNCthMoFsvu7be42Sgejax2+7frRjOYNHa22IE2nPhUp+00HR4N najuNd0VqNcAOqMDs74qmxqqGC1EI8duNqX3YRDiqusLSjxV5avK336yeSiRMYCsKCx/gXx0wXrS feXjB2S6vGoHqLMwdV1QVMvXLUQdHx99QMYAoqKwCg/bbhKwK1vrzo6BIEHUEkL+VIXozShW5SBL j6GRE+IUkKlCVAI8EvCRuZcaW0Z7ABdtv909hBmZLYDapMLc9NkkpPcukoQMSlLFEFUNavoCtTpY t4wBF2WpbhHYC2Wrm9Vi1YWmyyISQwn24GUy3h5AxtCI5t2C3wmU0bDu9wzQeHgGaDg8AzQcngEa Ds8ADcfwMUBrWDZJm4E8A7jpsk0qm9CJqgvRorsrr2KD9oMwNCjnLt5NFTNaozxdEiZpGcNVdVmf YR/dAF4HMgOYd6nNu93JqG7RVbJAmG6Uqs/uRaJ/NA3R1cRPvlVzqi5Kn/Iay32IjAFkd+9FZPpw ncv0gCDu/m1lXmbRHon+bUYNZ2eT3NX5yxYF+VTc3Ec0DsnRsKzJzB6vbZqspPurz+PbTq6c1af/ 9U7VE2O2jL6ProCvg4QBkqY1mUyBeGmCGvWvRNHJDzn3fBnkixCKJdyU8g5o2BFQPbLDoWKT6R2M 2G+9cL1WQkePWCAsrCMSRbDaK79cnl65lW8AyrwFZE2ss8mzXclkoo+m1C4QFORAIOSumojM9kSy +wiPFGXeAsxGVTYnZzbfHdsp1eU1MnB8lsBmsNZYuF8YYZsiegPzGqAOGnj23wXD5iDCd9IuY/h0 AR67Cs8ADYdngIbDM0DDsZ8YYCLdaZjoS/oHORz/G7alcw1EDDAdN9wK05VT+pRF029DyFnJWqBs J06wln5fU8aeqMUeB3mLm9hhh5t4S8kCE9bSH4+pusMYerotJnwo98+cQ9pL0cGQkAe4BLRYEgJn r2TT6fMZljVJZ+fqFjhrOFlUTD3CLC8KXQhznJcady0XfpL1EnS5hKrSHedl6fcJXpF+H+YmNhgB dmjzfd7UtoA6Dxdn0vqbP22XYkchspa31THdOk84+RIAq5pduCUFg6wyhQ4LmgKMpN92CrRFnkCP NSLHEhE2CVmTclhjUmKByRzdjpeF0kUlzMffYIQjwETMCLpywqSC4lqaOpfPmyGyeJpSwgAb8ado hiEW+RLwfXaM27SH48+z2hCHDLHneJF5A31GckExI8kqgHWBBVSjP38+t9ghh3gj/X69sgxHuJ6A awylvNNAM0tAszo+UKRSjsGT7v9N/kF8nM1lXUsC32enEEYuQsQAo4bUdOMGbBIAnk9ZIGSG5xUh EhYodn+EVu6zWLobjCVt8yPuAL5JWxl/HVIWUpdgMpZUk4UJq99Iuv93GZFZwHU9q+r+YgOCWVBF Y+dVJc0mARIWQNP9xLmjXeSdyH3mcZjX4283KqhHuEybDaDNZd5RWAPkNalVj5naBb0txO/z5cKz qPsXOAJ8HSCZwN1fA4vdn6/gNVzDNYxwjVZIXs3VXA2oRtiipfthjOeZYYbnNeacE2wxzTRbFdf5 I/xi/G+kUL4x3kXIG7Rpc4CQdxlNSic1nX9U+NPhMDbYQnxJ8Sxi+rO8jb8BYIrViFD9jbZYxRFr nO8ZQtokwBhbEI/9LUXzT0h0FQv8fO4z30TRKGkTrYhkOfFONkB4L9igbbAoqiPgd2qGUNt0vBLX L1qfpd1vYgBxJVsUOsXu/zNelH4VYRaJ5jXApOI1rwwd4J25z3wTReuLg6wVXgGzRbL4JL9Msy3y 4KvCXxFzLArfq4XQ45WUxYXuHyYHERPArwq/X9QspPqLEBTd38vUIwxG7X2cl+XuHyYG8BgI9pMu wKMCPAM0HJ4BGg7PAA2HZ4D9hU/z6XIRZAZoORzM1sPl5k03TCg16pOCLrv4lj9NKP2bztHnc3TV ppOoLT/eBzrAn1vap0Oncrtdxyf4BNdZQs0yy2zyQ3wNbNFlElhT2OavcEe8A/UwSxxjSaGxfoJ1 zgILTDAv0ct50Ex0+3L4Sb4bP41SuyW39RPpwxOcLcR31ce3gWjjp/f0JEwAzEr2DgAdVhilC4zS zb+v06ILLPAE85wF5fmJZ7kNeI5fN7TubLyZNMcqr4kMEHV/pE0rskDIeO48fdnbw6PzhB/lcT7K 4zzAI5oGmmCdaZYKOj3x6KcqB5fr27/Ne7nEKf6JX9P4OGhzmZCAk4WdvowOGOivcIVDHFfSk+af AxZLtmBCXUjV7SJ9vqCEX1DurE6zxBzLdBODG1EdnGynrjFZyVGLaCug1hzeyiY/4N94nRc1OsEJ 1phhWavSrYO/5z1cpM1FbuUftaGivfS2kS7vWcq4orAVSpCMvkUldVRqNZ3lhdra4kaHJwD3A6Px 9NhiO1sDnJV209eYNJh16LDNNl26bGsPd/0zv8O3mOXrLBQMOiDp/iUm+rIN/Ft8ldN8g9N8WWm4 cRNgOh+Z0AMCrtLSD3FYY/gyK3V8fi+/E3d/cnqyW2ot8Ek+I/3+DJ8shDnKUTrAIywyx/mol8Q1 QAjxGkAlwO1TQEA2w4VK+nvZ5Da+w3v4Du8paK2T7lePfnEfXbWmiBzMdAWDlDz9K3yIJ/kwT/Jh vsYZjQuJNqCawzP6VfzESFfHz+beCM/mbBA7rKS1iuonrwJaOalaXAOYbw/P2E+i5bWB+pHXZYZl jsaiW28PqMNkYY6TGcDc/XJFbSYR28qnf8wR7uMG7uMa/pQzEm2cH8bfNuLPEz2lZ91/XlPm1XgK SGqW7+BtaYoodn8LgOeA24jFey7/aO5flaPlJYA4ivONbkYUohU3f3l7mKji+u5P3gISqN4CRlMX NcU6mBeJycz+L8bS1aEHhIbuV5VQ5UgrYgHVG8D7uMhHeAKY5y85zd9J1FkWeYAui/m4mQQQTRKr dOCCVIEFZRjblSym0b/GLQIL3FLQ/5/gZbpky88TCrr8Ow+b05g69Dlr98NU7jWwiG2BxfO4wu/x FQCeoMsVRYhHgLl8XFd18Mn49cej3+hAXkz3BLMARRb09gANh9cFNByeARoOzwANh2eAhqN5DBCp jTsKSidV5d7kkI5O17fHPBKLDHAybYCTldOr7h+gLlqEnIu/n9NaNTwU6yBWCizwG6xwhjO8m3fz PX6pEDNqnY/Hv8SbjiOc4gOE3MqthHyAU4X4ZvcVeWuGvD1DkW4LMV3IQ6YnFUlfA0+ywSp/ASzS StWexURcXEn2x+p9lkXaXOYkG4pNlSjnRe7mXLzfrt8PP8arFHcKj6Tf3+LHir3QRZ5iiTaX43Tk vXq7OjzR73WVimTz3muo0A52cyGC1FBmTeHKN2RUiJGqszMJsMEqUyzzQVpsK07CDB6LwAazbKBS qCZ77Un3q1SuR+NPtSr6TX7MDjv8mLeU9KdYBkZTnf5q6RqcoJteiVGUA4kdlE6GbjMX61rV+tYw TmUCtFL4XYwzzjj/lTzIJEDIDMucYy7mdLM9iy57EWXkgO6GAhEnBbZUSahzgop1kbsL9Lw+LT9C ssFwjJcLuT/KxwBYpQNKCSSeeNxRSgB9/iEjscXViDKFSAJ0IVbJvVa4XCeRABPAWaUz75A2B4Cf AunRNlkbGHX/3UpPQWHuWzVlj675XXA5PRs3p5yg7oZ09Ku7X7R5yO+1P8lPU/3AyzxWiP9xLpCs HdS7+oeUO/CuOJJ+/gj4WUWIjwGwxAxLHFPIgJDsWGpxQE0A/w38lAP8HC/wcPRYlADbtOKmW6FT weQLYwg3gydTDjYJ8EX+IP2et4uTu1/VgSe5X/j1KV4z5K5isGiM/gSAK1oJoPMiFHJMeh7yWkEC iPIj0u2VWwPcDPwnAD/MWjcTe21abPMU06zQUZhEZStetc9v8akqRJD7Z6aqctiIOy/7LiLp/khG 3MazEjXp/ilGCZTj9zKfYy7+V+x+2GCRB4CHiVYaRWyzzf/xNq5SnuCftDjYuJZreZVruS7+3wzV 2WDbGuBGDnADN3ADcHMSIpsCIv8X0UtSeyh1f3PxW8AlNhQNEHX/c9zNu7mNyCxCRNT9q4b0L7HI t4FfUHQ/wBdZ5RFWeYwuc6CQAhCJWRXWBTOW44XzxzPx4frs/5lciFYqI5LfeYhmMmqTGYVnhLLa wEG+BprRopsK/me5Lac1j8zd7LZGaMsfLTG3OcZ2vJw8kHMJA/fwEq+zpW2lkCA9L5BfZh7mV1iL TfIm+decaem0woZSdtmXD1F06Kf0X+DVwSLewcPAg5pRPMsoizFbtfhffqbAYiJUDCB6M+yH3XMF eAZoOJqnC/CQ4Bmg4fAM0HDkGWBa6y/8Ts6nmqTzRpeoHnsI8iJwiWlgufAOCn/EZ3NP7uNzgy68 R32IEuB0PPqnOZ0LdWfa/dkO3WeVUmCN0OAm8dVYgnSs5bKH2H2sCdr03fb12zeIDLAAjDJK8VjH GWVc1dMJMDhqPRp/rlhK1VEYbMBs3Piz2ni2EDZ6KFw1UeziSc33PY1sCjjNN8mOht3BRalhNLEL T+w7gS3FwU0ZyTFJeeN2VvKSeV4RzxZilkVO8wy3c1GTgptDd1sN9xQyCRCN+la8x7ygCW+7eXfB EDdKv4v65Esn/VR1v2zgoT5fH5lpjMbuF1T00zzNmzzNaU0KwHDsz+0eEgboxPN/N9ZZTVechf89 /tOhC2woFpmJ0Nd1vyuW2dZeagPP5D4zuNgyTgDrrLMOfbqWagBIpgBRDVJUiciir44gjM7wbuee Zt2u7367K+YQmGOZaRZRC/DTPA3A+7moTWE97dx8CPEqqvX9sgqIJEAn/d0S1IzZ08eVcVVPO5Y1 fkCgsGVJ7h8yjf45zXf56SLd1AtPkX6R93OY93PR4Gt7womyzySAbZH3Pr6loP527gx6lpJeMujV yXbhb3eyYAtho4essxCvAtY0Y7zqTSBDiogB1PfsiWLuHj6fo97LFxRxOqwY52+TPYEt7nBgXzKA C25nOjZLhMdYViykmoHGMoDHvoTXBjYcngEaDs8ADYdngIbDM0DD4Rkgj47Fm/8ecwBhg8gAoVIL jxSiV1dCDApnLU6wO0ZbhY7VkmHPQZYAHVasTKBGxjwtbQodVmJNQ4eVAgvJ7DevoM9LKalYsOD/ olCCeeYN9XPvfherpj2BvK/gCKs8rNyS1XsTDqV4Ifk9/ajxAqDDg3HjmVKY52yBHl2BoIsv18Ds wyAw0GwpJ9R9siOoXgN0WLHe5a2Ll3S0OEZD4alZwiQp6FBVQkWlKH6rm9Keh5oBVpkyXuWswypT TJFIgGyEBMJTs7onSUEHW/zdwb4Y+xGKDLBasZGTeC1WmCLIpbBKwBQrtAzpu+VctXyyDwI1dcoY V6SGFW5MGErIawDd3J+F0N8oMPwwz/IRsrVKeeqehNcG5tFhxdDFZuoehGeAhsPvBDYcngEaDs8A DYdngIbDM0DDkWcA09lbj32IjAFasavUG7lR42s/0rM9pKF67EkkDNCimzqHOUZX2cltpniMB+k6 XCiRV5fM564rmN9luocGyUbQOeb4LPcT8hAPEyrdIUdosUTH6ky26Ko4/1t2lNhvuocGEQO06LLB KeBBnmGVS7Q1t1Mv8ileY4WO5gLTKJzKV/VI7E79EFc4VPCnHXI9b3C94HBdTX9D608/ou3EfyqP /R4KRM6iTwAXAGIv8hdoc6IwgtqcYpE5jjFDlzkeLZXT29Nv6tu/r43/1JfPw3Xx39tR6+OvBUZj +qjvfFfkJUAEtQRIQq4yxTnmtO6Q1RLgl6XfLxVEeH/pHhpEEmCbVTrMxoemZ2mzqrmRImCGJY7y lOGEvQoLvJT7vb6rdA8NkkVgdB/GBhe4izbqGwMya4ApUKhFxdG/Tyzm9j/Ea+Meil8El3loKC+M 8OgDvD1Aw+F1AQ2HZ4CGwzNAw+EZoOHIGMB2H0Bd+u08mtIf5fZdp/e7foOmV0TyFmC7D6Au3eZm rt/0ftdv0PTKiBjgTv5WQfsA34i/1aXbHE32m97v+g2aXgPRFJB5/hePTZ1RfBORp9+bXi17b45+ l5A+iqd3qZLX0IMK8c8o46vqZ6u/WP7y8delg2m6+Ca6WAp1r5RE3lWs2hm0zZVs5iD2HuAL0pPe pe8S356+yh22a/wA9QGzsMTvUEilSP9DAP5K237J01O8QE8OqYkMIOvXiwWw0ZN5N5uP1Q2sayB7 +oEyNdcOsKdvZoD67ROkz6vRb+YFoft7wgAH6ych4CfC/+URWiWCGeJx9CopBMJnlfihQ1ybmuwj BtrNXJK6vyfo9RQwC5yn+hRQX8Try1dMoZoIN6XvJkFsEkqX/81ckrq/BxIgWgTa7gNwo98DLLIY fxPp4gtZqHj6BYFqo2Oko6TL5Q8LTx+XKDZ61fZJ6hdWpr8gdb8615KIGOCCVIAEFxTfROTpn08b 8PM5+teE9FE8/ZoqeQ09rBD/gjK+qn62+ovlLxs/77yqLB2QhL+6V0riqlGAV/gPPpij3MtX0+91 6T/gf7gjR7+PL+0avd/1GzS9BiIGgEusss1746eP8ScsSeHq0p/nu7xFO/7113xS6J7doPe7foOm V4Y3CGk4vDaw4fAM0HB4Bmg4PAM0HJ4BGg7PAA2HqAxyvzx9OOkeFSBrA0fSbzvK0HXpHkOH4hRQ r+t2rCnUG7lB7RQ8JOQZwNaBO+wY6Yl7Bh1sHajz5Z0grKjr99AgzwAjYOzAEUaM9MhDhx4hZoMJ 04UvYDeo8CiJ4hQwUiEVObY5hXrj18ZAHiUhLwJt839dusfQQWQAm2gddrpHBfiNoIbDM0DD4Rmg 4fAM0HB4Bmg4PAM0HHuXAcb8hlAvIDNA/X22kAlCJvpe7jE2Ge97Lg2AzADj8d+gYRvdUfdvDbqY +wEyA2zGf4OFbXT77u8hXCVAyFjhrxzCwj81ou7Vs2HS/X4N0BPIyqBNAjY1d2sX/8ph0ilU0v3j RvqWXwP0CjIDmCTAeNo1yV85IbxWeFJkojEhfRWLyd3vJ4EeYJgkgO/+AcBVAtSH/QKHct0/pgnn UQquEmA3YJIuqu73a4AeoNcSoF9Wu4nQz3961IT3D9Bw7F1dgEdP8P+NTFhDa6AzzgAAACV0RVh0 ZGF0ZTpjcmVhdGUAMjAxNi0wNy0xM1QxMDoyMTo1OSswMDowMBsBiYsAAAAldEVYdGRhdGU6bW9k aWZ5ADIwMTYtMDctMTNUMDk6MjY6NTQrMDA6MDDzzaAQAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJ bWFnZVJlYWR5ccllPAAAAABJRU5ErkJggg==');
        }

        .ui-state-default,.ui-widget-content .ui-state-default,.ui-widget-header .ui-state-default,.ui-button,html .ui-button.ui-state-disabled:hover,html .ui-button.ui-state-disabled:active {
            background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAGQEAAAAAAao4lEAAAAAmJLR0T//xSrMc0AAAAJcEhZcwAA AEgAAABIAEbJaz4AAABISURBVDjLY3iXxzCKRhHV0bNnDM+NGJ7fYXgxk+FlJsOrOIbXIQxvYhje pjK8i2Z4H8DwwZjhIzPDx7UMn+QYPhmOolFEDAIAjUD2JAAuNW8AAAAldEVYdGRhdGU6Y3JlYXRl ADIwMTctMTAtMzBUMDI6MTY6MDcrMDA6MDBANiUPAAAAJXRFWHRkYXRlOm1vZGlmeQAyMDE3LTEw LTMwVDAyOjE2OjA3KzAwOjAwMWudswAAAABJRU5ErkJggg== ');
        }

        .ui-widget-header {
            background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAABkEAAAAAAy19n/AAAAAmJLR0T//xSrMc0AAAAJcEhZcwAA AEgAAABIAEbJaz4AAABaSURBVBjTY3h8jYFOaAPDo/cMj/QYHuYyPGhjuF/BcC+L4W4swx0Nhltf GG7uZ7jRzXA9nOGaEsOV4wyXdzJcamW4WM5wYQLD+SaGcwcZzt5iOOvAcObMACIAsZae6pVZewYA AAAldEVYdGRhdGU6Y3JlYXRlADIwMTctMTAtMzBUMDI6MTY6MDgrMDA6MDC2flXmAAAAJXRFWHRk YXRlOm1vZGlmeQAyMDE3LTEwLTMwVDAyOjE2OjA4KzAwOjAwxyPtWgAAAABJRU5ErkJggg== ');
        }

        .ui-state-hover,.ui-widget-content .ui-state-hover,.ui-widget-header .ui-state-hover,.ui-state-focus,.ui-widget-content .ui-state-focus,.ui-widget-header .ui-state-focus,.ui-button:hover,.ui-button:focus {
            background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAGQEAAAAAAao4lEAAAAAmJLR0T//xSrMc0AAAAJcEhZcwAA AEgAAABIAEbJaz4AAABISURBVDjLY3j6n2EUjSKqo1u3GG57MdxxY7gby3BvIsP9PwwPMxgefWB4 Us7w9DHDcz+GF/MYXl5ieHWW4XUpw+uJo2gUEYMAvlejJVIWsXwAAAAldEVYdGRhdGU6Y3JlYXRl ADIwMTctMTAtMzBUMDI6MTY6MDgrMDA6MDC2flXmAAAAJXRFWHRkYXRlOm1vZGlmeQAyMDE3LTEw LTMwVDAyOjE2OjA4KzAwOjAwxyPtWgAAAABJRU5ErkJggg==');
        }

        .ui-state-hover .ui-icon,.ui-state-focus .ui-icon,.ui-button:hover .ui-icon,.ui-button:focus .ui-icon, .ui-state-active .ui-icon,.ui-button:active .ui-icon {
            background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAQAAAADwCAQAAABFnnJAAAAAAmJLR0QARaw7li0AAAAJcEhZcwAA AEgAAABIAEbJaz4AABptSURBVHja7Z17bGVHfcc/Z7NL1tkkvYaWyBZV9iGaPlTt3diIpEqV67Zp NkEi9laUqlIlO4nsItQAkSpVUCmPCvUvkhQUtRvBeosEUkoU70YUFvqwUVALwc56lZZCUR5IxVZV 2uumfxiUwOkf5zVzzrzOOff6Xt8z35X33nt+8/795jdz5jfzm+AOPJqMA4MugMdg4QWg4fACIGOC kIlBF2Iv4QVAxARbwFaTRKDXAjD4/jNBWDnmFjCJTgSSlAdfxx5CFgCzAgzTfybY+o8+fhjnPqEN Y8s7YWK1GkTs345FwJTyCOkIUQB6oQAna6SQxE36YXnUiQsBAdvANgGBIeU6dRw6BOk6QFLFpB/o EEKheURE6QSV4ie9TJe/Le+wZtldU7bVcR8h0wBmBegKUx+0Dx9R7iYWmlOp1zdNQ5CYcj09M2QI Sq8EmnuRqQ9mjVq179hTMPdNc9nNOjBL2aZn9hXKvwUEFvbpmyZI/1WFPYVtY880551pP1UdxJRH hv1VNMBoY4KtUWKvHQcHXYAhw/ZoTO3c4VcCGw4vAA2HF4CGwwtAw+EFoOHwAtBweAFoOPx+gHzc QZd/j1FmP4DbjgCbMWbCuB/AnIOdPXX2A9jN4VHZR0pIyu0HcLOAmZtQz6BJzXfXtG3st6W+lfvU pz4yuwGK+wEi6FfDk1Ame5uebovtsh/AVDpz7vb4ZoRx2snnSEDeD6D6LmPbSQuow9j7p8t+AFP/ cyubXnxC626DMjntC2QCEEj/9LCLgK6JXdTzdrwty4wtbeyqZYto8qc+9RGyF/baHBwOvHEm2Kqs nhtnDO69OXjwI2Mdg27jjMF+Iajx8ALQcHgBaDi8ADQcXgAaDi8ADYcXgIbDbwvPIxzgWkD9s1Ol y3+wXvS+NMIgSxBaS1DdFGSPOYCay0NACEZbv4t/gLACpSyq5mErf8T6wJiKXTiqxnargUuoEnEP SAFs1Xc516ePHzg0kEsVQoO516V8gYEmf5bLI6HYW8BcQ7MAhZbYYOvEUvnFIcC1+rrdOvZGCnqg 4EOjtd82itYpQZjGDpRUMXdVLkn30pchNNDNaWe1M3cDsZQBlJ0Ehg69xxbKRTqr9XE35gYOqZsY 5JJu1RYwdUGXtO1tUKCXeQ3MVJxLKDXNrALtEmxOw6Zi3VS0rQfZcneZRFaFXcTtdKkEZTSAm+qs N8sNHLVMv8oYGBWsW7qBQ5iqMA/T5gFQGfegJtDgMOgS7Of8K8T1K4ENhxeAhsMLQMPhBaDh8ALQ cHgBaDi8ADQc8uHQxFnq4GD3B95PuLSAi0W0Wjzb2WjXXEohE4Dk5J6Lu/dqDdA7VEvLVnK3FjC5 ms2scROlY8uH8/R1mKjcAmGulID6cKj5DJ+LRXtC8ax3IqBLy801hL78bi2gy2Mid7x2olTsrAY2 DVTvaHrhgK58NtDFnbrtCLbOmbLbThp7CXTp2F2420vu5pBebTEosjbI0W0HyzPmqM4nhlLKZoOx zmAdFMOUnQTqqyCPX8U+FKTxq2qCLK4q/y1FKfRlqJt7+VX3LJauDVx1sA6Tim9WlBOAOg1gb/6E baZLZbJ0quVfVwT0uU/G1GQEVzPBlH+QWhMDDdWUcnZ83X4EXphnlNsPYGoAeQJjqr65cKYqmtIQ q2bf9qVigV0ATTXYzjmQ2C6dghtM7N1Or71xKyXlBMC959uvjDAVznZjiGPVStfDRQBNNcgOlweW a2uqI0nZPAibBsDcEXh/X4CICeuNSSMHfzBEhHcQ4dE0eAFoOLwANBxeABoOLwANhxeAXmOQ5uwK yO8HsMFkr3Kp+kRNe3e/Ub90gWWxe8jqXtwPYILJYu5yLi+x2E06HDDVo+7hKvPx8MB6/NXOYF18 U+oDQrYSKBbLZSm3aA7Nji9Wu/3b7dyuySJhTyGMb/8NLLF15l7T4dHQiepe0z2Beg6g23Rgtldl Q0OVTQtRz7Fvm9L7MAhxtfUFJZ6q8lXlbz/ZPJTIBEA2FJa3SEcXL+v3A9gQkNnyqh2gzsLUdUFR LV+3EHV8fPQBmQCI1rQqMmyzxtmNrXVHx0DQIGoNIX+qQvSmF6tykLXH0OgJcQjITCEqBR4p+Gi7 lxrbxv0ALsZWu3sIM7K9AOotFeamzwYhvXeRJGRQkiqGqLqhpi9QWwO3DBV0MZaqwmwz6WhstXnX cJvo6eLX8TBi3tVnv0zGfSDZM6gFoPwkySVcL4ytLilUd1HhIgJ1Szdk8CuBMvYhC+vBC0DD4QWg 4fAC0HB4AWg4vAA0HMMnAK1hWSRtBvIC4GbLNplsQieqLkSL7p68ig3aD8LQoJy7eDdTzHiN8nRJ hKRlDFfVZX2GEboBvA5kATCvUptXu5Ne3aKrFIEwXShVn92LVP94GqKriZ98q+ZU3XyCuYHIBEB2 915EZg/XuUwPCGL27yjzMqv2SPXvMG44O5vkrs5f3lGQT8XNfUTjkNgCsiYze7y2WbIS9lcfx3ec zDUq9otly5c/2cyW0UfoCvg6SAQgaVrTlikQL01Qo/6VKDr9IeeeL4N8EUKxhFtpqKSUjToCqkdm DRSbTO9gxH7rheu1Ejp6JAJhYR6RGILVXvnl8vTKrXwDUOYtIGti3Z4825VMJvp4Su0CQUEPBELu qoHIvJ9Idh/hkaLMW4B5U5XNyZnNd8dOSnV5jQwcnyVwdx/RMLhfGGEbInoD8xygDhp49t8Fw+Yg wjNpjzF8tgCPPYUXgIbDC0DD4QWg4RglAZhKVxqm+pL+QQ7H/4Zt6lwDkQDMxg23ymzllB61WPpt CDkr7RYoy8Qp1tPv68rYU7XE4yBvchO77HITbypFYMpa+uMx9bgmDz3dFhPel/tnziHlUnQ8PORB LgMtVoTA2SvZbPp8jguapLNzdUuc1Swmi8iHmOclgYWwwHmpcddz4afZKEGXS6gq3XFeln6f4BXp 92FuYpMxYJc23+VH2hZQ52HzJi6HCZwpYois5W11TJfOE0m+DMCaZhVuRSEga8ygw5KmAGPpt90C bZmn0GOdyLFEhC1C1qUc1pmWRGA6R7fjZaF0UQnz8TcZ4wgwFQuCrpwwraC4n6vq1+FZUcTTlBIB 2Iw/xW0YYpEvA99l17hMezj+PKsNccgQe4GXWDTQ5yQXFHOSrgLYEERA1fvz53OLDDnE6+n365Vl OML1BFxjKOXdBppZA5rN8YEilXICnrD/N/kH8XE2lnUtCXyX3UIYuQiRAIwbUtP1G7BpAHghFYGQ OV5QhEhEoMj+CK3cZ7F0NxhL2uaH3AV8mbYy/gakIqQuwXSsqaYLA1a/kbD/dxmTRcB1Pqtif7EB wayoor7zqpJm0wCJCKBhP3HuaCd5J3KfeRzm+/G3GxXUI1yhzSbQ5gpvK8wB8pbUqh4A7IreFuL3 +XzhWcT+JY4AXwRIBnD318Ai+/MVvIZruIYxrtEqyau5mqsBVQ9btrAfJniBOeZ4QbOdc4ptZpll u+I8f4xfjP+NFco3wTsIeZ02bQ4Q8g7jltJpDfOPCn86HMYGW4jPKZ5FQn+Wt/A3AMywFhGqv9EW qzhmjfMdQ0ibBphgG+K+v61o/imJrhKBn8995pso6iVtohmRrCfeziYI7wWbtA07iuoo+N2aIdR7 Ol6J6xfNz1L2mwRAnMkWlU6R/X/GS9KvIswq0TwHmFa85pWhA7w995lvomh+cZD1witgNkkWn+Sn abZJHjwj/BWxwLLwvVoIPV5JRVxg/zBdGDEF/Krw+yXNRKq/CEHB/l6mHmEwZu/jvCyzf5gEwGMg GCVbgEcFeAFoOLwANBxeABoOLwCjhY/z8XIRZAFoORzM1sPl5k03TCkt6tOCLbv4lj9LKP2bzdEX c3TVopNoLT/eBzrAn1vap0Oncrtdx0f5KNdZQs0zz3zyQ3wNbNFlGlhX7M1f5a54BeoRVjjGisJi /RQbnAWWmGJRope78zex7cvhp/lW/DRK7V25pZ/IHp7gbCG+qz2+DUQLP72nJ2ECYF7a7wDQYZVx usA43fz7Oi26wBJPschZUJ6feJ7bgK/z64bWnY8XkxZY4zVRACL2R9a0ogiEsaNXffPZ1gqj84Qf 5Ek+yJM8yGOaBppig1lWCjY98einKgeX69u/wS1c5hT/xK9pfBy0uUJIwMnCSl9GBwz0V3iDQxxX 0pPmXwCWS7ZgQl1Kze0ifbFghF9SrqzOssICF+gmG25Ec3CynLrOdCVHLeJeAbXl8Fa2+B7/xvd5 SWMTnGKdOS5oTbp18Pe8m0u0ucSt/KM2VLSW3jbS5TVLGW8o9golSHrfspI6LrWabueFerfFjQ5P AD4EjMfDY4udbA5wVlpNX2fasK1Dhx126NJlR3u465/5Hb7KPF9kqbChAxL2rzDVl2Xg3+IZTvMl TvN55caNmwDT+ciEHhBwlZZ+iMOajS/zEuPza/mdmP3J6cluqbnAx/iE9PsTfKwQ5ihH6QCPscwC 5yMuiXOAEOI5gEqB24eAgGyEC5X0W9jiNr7Ju/km7y5YrRP2q3u/uI6umlNEDma6woaUPP0LvI+n eT9P836e5YzGhUQbUI3hGf0qfmKkq+NnY2+E53N7EDusprWK6ifPAlo5rVqcA5gu9BHFT6LlrYH6 ntdljgscjVW3fj+gDtOFMU4WADP75YratkTsKJ/+MUd4gBt4gGv4U85ItEl+EH/bjD9P9JSesf+8 psxr8RCQ1CzP4B1piCiyvwXA14HbiNV7Lv9o7F+To+U1gNiL841uRhSiFTd/+f0wUcX17E/eAhKo 3gLGUxc1xTqYJ4nJyP4vxtLVoQeEBvarSqhypBWJgOoN4A4u8QGeAhb5S07zdxJ1nmUepMtyPm6m AcQtiVUYuCRVYEkZxnYli6n3r/MuQQTeVbD/n+BlumTTzxMKuvw7D5vTmDr0BSv7YSb3GljEjiDi ebzB7/EFAJ6iyxuKEI8BC/m4rubgk/Hrj0e/0YG8mu4J5gGKIuj3AzQc3hbQcHgBaDi8ADQcXgAa juYJQGQ27igondSUe5NDOjpb3z7zSCwKwMm0AU5WTq+6f4C6aBFyLv5+Trur4eHYBrFaEIHfYJUz nOGdvJPv8EuFmFHrfCT+Jd50HOEU7yHkVm4l5D2cKsQ3u6/I72bI72co0m0hZgt5yPSkIulr4Ek2 WeMvgGVaqdmzmIiLK8n+7HqfZ5k2VzjJpmJRJcp5mXs5F6+369fDj/EqxZXCI+n3N/mxYi10medY oc2VOB15rd5uDk/se12lIdm89hoqrIPdXIgg3SizrnDlGzIuxEjN2ZkG2GSNGS7wXlrsKE7CDB7L wCbzbKIyqCZr7Qn7VSbXo/Gn2hT9I37MLrv8mDeV9Oe4AIynNv210jU4QTe9EqOoB5J9UDodusNC bGtV21vDOJUp0GrhdzDJJJP8V/Ig0wAhc1zgHAuxpJv3s+iyF1FGD+huKBBxUhBLlYY6J5hYl7m3 QM/b0/I9JOsMx3i5kPvjfBiANTqg1EDiicddpQbQ5x8yFu+4GlOmEGmALsQmudcKl+skGmAKOKt0 5h3S5gDwUyA92iZbAyP236v0FBTmvlUz9uia3wVX0rNxC8oB6l5Ie7+a/eKeh/xa+9P8NLUPvMwT hfgf4SLJ3EG9qn9IuQLviiPp5w+Bn1WE+DAAK8yxwjGFDgjJjqUWO9QU8N/ATznAz/Eij0SPRQ2w QytuulU6FbZ8YQzhtuHJlINNA3yWP0i/5/fFyexXMfAkHxJ+PcprhtxVAhb10Z8A8IZWA+i8CIUc k56HvFbQAKL+iGx75eYANwP/CcAPstbN1F6bFjs8xyyrdBRborIZr9rnt/hUFSLI/TNTVTlsxszL votI2B/piNt4XqIm7J9hnEDZf6/wKRbif0X2wybLPAg8QjTTKGKHHf6Pt3CV8gT/tMXBxrVcy6tc y3Xx/2aozgbb5gA3coAbuIEbgJuTENkQEPm/iF6S2kNp+1uI3wIus6logIj9X+de3sltRNsiRETs XzOkf5llvgH8goL9AJ9ljcdY4wm6LIBCC0CkZlXYELaxHC+cP56LD9dn/8/lQrRSHZH8zkPcJqPe MqPwjFDWGjjI10AzWnRTxf88t+Ws5tF2N/teI7Tlj6aYOxxjJ55OHsi5hIH7+DbfZ1vbSiFBel4g P808zK+wHm/Jm+Zfc1tLZxV7KGWXffkQRYd+Sv8F3hws4m08Ajyk6cXzjLMci1WL/+VnCiImQiUA ojfDfux7rgAvAA1H82wBHhK8ADQcXgAajrwAzGr9hd/N+dSSdN7oEtVjH0GeBK4wC1wovIPCH/HJ 3JMH+NSgC+9RH6IGOB33/llO50LdnbI/W6H7pFILrBMa3CS+GmuQjrVc9hB7j3XBmr7Xvn77BlEA loBxxike6zijjKt6OgUGR61H489VS6k6ig0bMB83/rw2ni2EjR4KV00UWTyt+b6vkQ0Bp/ky2dGw u7gkNYwmduGJfSWwpTi4KSM5Jikv3M5LXjLPK+LZQsyzzGm+xu1c0qTg5tDdVsN9hUwDRL2+Fa8x L2nC227eXTLEjdLvoj750kk/VeyXN3ioz9dH2zTGY/cLKvppvsKP+AqnNSkAw7E+t3dIBKATj//d 2GY1W3EU/vf4T4cusKmYZCZKX8d+V1xgR3upDXwt95nBZS/jFLDBBhvQp2upBoBkCBDNIEWTiKz6 6ijC6AzvTu5pxnY9++2umENggQvMsoxagZ/mKwDcySVtChspc/MhxKuoNkZlFhBpgE76uyWYGbOn Tyrjqp52LHP8gECxlyW5f8jU+xc03+Wny3RTLzxF+iXu5DB3csnga3vKiTJiGsA2ybuDryqov507 g56lpNcMenOyXfnbnSzYQtjoIRssxbOAdU0fr3oTyJAiEgD1PXuimruPT+eo9/MZRZwOq8bx27Sf wBZ3ODCSAuCC25mNtyXCE1xQTKSagcYKgMdIwlsDGw4vAA2HF4CGwwtAw+EFoOHwApBHx+LNf585 gLBBFIBQaYVHCtGrKyEGhbMWJ9gd416FjnUnw76DrAE6rFqFQI1MeFraFDqsxpaGDqsFEZLFb1FB X5RSUolgwf9FoQSLLBrq585+l11N+wJ5X8ER1nhEuSSr9yYcSvFC8mv6UeMFQIeH4sYzpbDI2QI9 ugJBF1+ugdmHQWCg2VJOqCOyIqieA3RYtd7lrYuXMFrso6Hw1KxhkhR0qKqholIUv9VNad9DLQBr zBivctZhjRlmSDRA1kMC4anZ3JOkoIMt/t5gJPp+hKIArFVs5CRei1VmCHIprBEwwyotQ/puOVct n+yDQE2dMcYVqWGFGxOGEvIcQDf2ZyH0NwoMP8yjfIRsrlKeui/hrYF5dFg1sNhM3YfwAtBw+JXA hsMLQMPhBaDh8ALQcHgBaDjyAmA6e+sxgsgEoBW7Sr2RGzW+9iM728Maqse+RCIALbqpc5hjdJVM bjPDEzxE1+FCiby5ZDF3XcHiHtM9NEgWgs6xwCf5ECEP8wih0h1yhBYrdKzOZIuuivO/ZUeJ/aZ7 aBAJQIsum5wCHuJrrHGZtuZ26mUe5TVW6WguMI3CqXxVj8Xu1A/xBocK/rRDrud1rhccrqvpr2v9 6Ue03fhP5bHfQ4HIWfQJ4CJA7EX+Im1OFHpQm1Mss8Ax5uiywOOlcnpr+k19+/e18Z/68nm4Lv57 K2p7/LXAeEwf98x3RV4DRFBrgCTkGjOcY0HrDlmtAX5Z+v3tggrvL91Dg0gD7LBGh/n40PQ8bdY0 N1IEzLHCUZ4znLBXYYlv535v7CndQ4NkEhjdh7HJRe6hjfrGgGw3wAwozKJi7x+RHXOjD/HauIfj F8ELPDyUF0Z49AF+P0DD4W0BDYcXgIbDC0DD4QWg4cgEwHYfQF367Tye0h/n9j2n97t+g6ZXRPIW YLsPoC7d5mau3/R+12/Q9MqIBOBu/lZBew9fir/VpdscTfab3u/6DZpeA9EQkHn+F49NnVF8E5Gn 359eLXt/jn6PkD6Kp/eoktfQgwrxzyjjq+pnq79Y/vLxN6SDabr4JrpYCjVXSiLvKlbtDNrmSjZz EHsf8BnpSe/Sd4lvT1/lDts1foD6gFlY4ncopFKk/yEAf6Vtv+TpKV6kJ4fURAGQ7evFAtjoybib jcfqBtY1kD39QJmaKwPs6ZsFoH77BOnzavSbeVFgf08E4GD9JAT8RPi/PEKrRjBDPI5eJYVA+KwS P3SIazOTfcBAu5nLEvt7gl4PAfPAeaoPAfVVvL58xRSqqXBT+m4axKahdPnfzGWJ/T3QANEk0HYf gBv9PmCZ5fibSBdfyELF088IVBsdIx0lXS5/WHj6pESx0au2T1K/sDL9RYn96lxLIhKAi1IBElxU fBORp386bcBP5+jPCumjePqsKnkNPawQ/6Iyvqp+tvqL5S8bP++8qiwdkJS/mislcdUJgFf4D96b o9zPM+n3uvTv8T/claM/wOf2jN7v+g2aXgORAMBl1tjhlvjpE/wJK1K4uvQX+BZv0o5//TUfE9iz F/R+12/Q9MrwG0IaDm8NbDi8ADQcXgAaDi8ADYcXgIbDC0DDIRqD3C9PH066RwXI1sCx9NuuMnRd usfQoTgE1GPdrjWFej03qJ2Ch4S8ANgYuMuukZ64Z9DBxkCdL+8EYUVbv4cGeQEYAyMDxxgz0iMP HXqEmDdMmC58AfuGCo+SKA4BYxVSkWObU6jXf20C5FES8iTQNv7XpXsMHUQBsKnWYad7VIBfCGo4 vAA0HF4AGg4vAA2HF4CGwwtAw7F/BWDCLwj1ArIA1F9nC5kiZKrv5Z5gi8m+59IAyAIwGf8NGrbe HbF/e9DFHAXIArAV/w0Wtt7t2d9DuGqAkInCXzmEhX9qROzVi2HCfj8H6AlkY9AWAVuau7WLf+Uw 7RQqYf+kkb7t5wC9giwAJg0wmbIm+SunhNcLT4pCNCGkrxIxmf1+EOgBhkkDePYPAK4aoD7sFziU Y/+EJpxHKbhqgL2ASbuo2O/nAD1ArzVAv3btJko//+lRE7IAbMd/w4dA8+lRE/vXFuDRE/w/97Je qtfGCLwAAAAldEVYdGRhdGU6Y3JlYXRlADIwMTYtMDctMTNUMTA6MjE6NTkrMDA6MDAbAYmLAAAA JXRFWHRkYXRlOm1vZGlmeQAyMDE2LTA3LTEzVDA5OjI2OjU0KzAwOjAw882gEAAAABl0RVh0U29m dHdhcmUAQWRvYmUgSW1hZ2VSZWFkeXHJZTwAAAAASUVORK5CYII=');
        }

        .ui-state-active,.ui-widget-content .ui-state-active,.ui-widget-header .ui-state-active,a.ui-button:active,.ui-button:active,.ui-button.ui-state-active:hover {
            background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAGQAQAAAABHIzd2AAAAAmJLR0QAAd2KE6QAAAAJcEhZcwAA AEgAAABIAEbJaz4AAAARSURBVCjPY2hgGIWjcBTigACVaMgB0zSxaQAAACV0RVh0ZGF0ZTpjcmVh dGUAMjAxNy0xMC0zMFQwMjoxNjowNyswMDowMEA2JQ8AAAAldEVYdGRhdGU6bW9kaWZ5ADIwMTct MTAtMzBUMDI6MTY6MDcrMDA6MDAxa52zAAAAAElFTkSuQmCC');
        }
    </style>

    <link rel="shortcut icon" href="data:image/ico;base64,AAABAAEAMDAAAAEAIACoJQAAFgAAACgAAAAwAAAAYAAAAAEAIAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAACQAAABYAAAA6AAAAewAAAK8AAADVAAAA7wAAAPwAAAD+AAAA8gAAANsI CAi3kZGRjcjIyFC9vb0aHBwcDAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACQAAABxAAAAtQAAAPAAAAD/AAAA/wAAAP8AAAD/ AAAA/wAAAP8AAAD/AAAA/wAAAP8KCgr/mZmZ/83Nzf++vr7/Hh4ewgAAAH8AAAAzAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAKAAAAoQAAAOwAAAD+AAAA /wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8FBQX/hYWF/87Ozv/Dw8P/ NTU1/wAAAP8AAADwAAAAuQAAAB8AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAABgAA AGcAAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA /wAAAP8AAAD/X19f/8zMzP/Nzc3/ZmZm/wAAAP8AAAD/AAAA/wAAAP8AAACKAAAADgAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAtAAAAvgAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAA AP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/LCws/8LCwv/Nzc3/qKio/wkJCf8AAAD/AAAA /wAAAP8AAAD/AAAA1QAAAEoAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFkAAAD0AAAA/wAAAP8AAAD/AAAA/wAAAP8A AAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/6Sk pP/Nzc3/1NTU/0NDQ/8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAPgAAACHAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAZgAAAP8AAAD/ AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8A AAD/AAAA/wAAAP8AAAD/AAAA/zQ0NP/S0tL/zs7O/8DAwP8BAQH/AAAA/wAAAP8AAAD/AAAA/wAA AP8AAAD/AAAAiwAAAAUAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAABmAAAA/QAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/ AAAA/wAAAP8AAAD/AAAA/wAAAP8CAhD/BQUg/wUFI/8FBRz/AgIN/wAAAP+OjoX/2NjR/9XV0v95 eXj/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAI0AAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFsAAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA /wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/DQ1V/xoarf8dHb7/Hh7B/x4ewv8eHsH/ HR29/xwcuP8oKKf/e3vQ/6Skzf/Dw8H/NDQs/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8A AACQAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAALwAAAPUAAAD/AAAA/wAA AP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wMDFv8cHK//ISHa /yAg0f8gINH/ICDS/yAg0v8gINH/ICDR/yAg0f8gINL/HBzQ/xkZ0P8bG9H/Jye4/xISdP8KCj// BAQZ/wMDEv8CAg3/AgIK/wICCv8CAg76BgYpVgAAAAAfH8QAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAHAAAAwAAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAA AP8AAAD/BAQb/x0duP8hIdT/ISHT/yEh1f8bG6r/FxeU/xYWj/8YGJf/Ghqo/x4ev/8hIdj/IiLa /yEh1v8dHdD/Hx/S/yEh1/8iItv/ISHW/x0dvv8aGqv/GRmf/xgYnv8bG6z/Hh7E5B8fyhkAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAABrAAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8A AAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8BAQT/ExN+/yAg0f8gINL/Gxuu/wYGJ/8CAg3/AQEI/wEB B/8BAQn/AgIN/wMDEv8EBBz/CwtI/xkZhf89Pdf/GBjQ/xkZ0P8dHdH/ISHS/yAg0f8gINH/ICDR /yAg0f8gINH/ICDR/yEh1K4AAAAAAgIRAAAAAAAAAAAAAAAAAAAAAA4AAAD/AAAA/wAAAP8AAAD/ AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8DAxL/HR3A/yAg0f8e HsH/BQUh/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP+Wlo7/zMzR/52d zv9jY7//FRWY/xwct/8dHbz/HR2//x0dv/8dHb3/Gxuv/xERaP8AAAA8AAAAAAAAAAAAAAAAAAAA AAAAAKYAAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/ AAAA/wAAAP8GBiX/IiLc/yAg0v8WFpD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8A AAD/AAAA/wAAAP8XFxf/vr69/9HRzf/IyMH/LCwi/wAAAP8CAgr/AwMU/wMDFf8CAgr/AAAA/wAA AP8AAADPAAAAAAAAAAAAAAAAAAAAJwAAAO0AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA /wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8JCTb/IiLb/yEh1f8REWv/AAAA/wAAAP8AAAD/ AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/Z2dn/8zMzP/Nzc3/gYGB/wQEBP8A AAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD2AAAASgAAAAAAAAAAAAAAdQAAAP4AAAD/AAAA/wAA AP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8GBib/IiLb /yAg0/8VFYP/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/ FhYW/7m5uf/Nzc3/xsbG/xgYGP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAAmAAAAAMA AAAKAAAAuAAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAA AP8AAAD/AAAA/wAAAP8DAxP/Hx/J/yAg0f8cHLT/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA /wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/3Jycv/Q0ND/1dXV/2RkZP8AAAD/AAAA/wAAAP8AAAD/ AAAA/wAAAP8AAAD/AAAA3QAAABIAAAAXAAAA9AAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8A AAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8CAgr/GBic/yAg0f8fH8b/CAgz/wAA AP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wkJCf/V1dX/zs7O /7q6uv8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAC8AAAA/AAAA/wAAAP8AAAD/ AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8A AAD/Dw9i/yAg0P8gINL/ExN6/wAAAv8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAA AP8AAAD/AAAA/wAAAP+dnZ3/0NDQ/9fX1/8ODg7/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA /wAAAHkAAACAAAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/ AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/BAQb/x4ew/8gIND/Hh7G/wQEG/8AAAD/AAAA/wAAAP8A AAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP9xcXH/09PT/9TU1P8vLy//AAAA/wAA AP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAALgAAACyAAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA /wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/xISeP8hIdT/ ISHV/xYWkP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP91 dXX/09PT/9TU1P8tLS3/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAOsAAADYAAAA/wAA AP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8CAgL/EBAQ/ykpKf9NTU3/XFxc /1lZWf9GRkb/KCgn/xYWF/8tLc//JyfQ/yIi2/8ICD3/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/ AAAA/wAAAP8AAAD/AAAA/wAAAP+5ubn/zs7O/9TU1P8JCQn/AAAA/wAAAP8AAAD/AAAA/wAAAP8A AAD/AAAA/wAAAP8AAADxAAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/xkZ Gf93d3f/ubm5/9bW1v/V1dX/1NTU/9TU1P/W1tb/2NjY/8vLyf+zs8T/nJzO/4GBzv9iYrr/MjIz /xISEv8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/BwcH/35+fv/S0tL/0tLS/5aWlv8AAAD/ AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD9AAAA/wAAAP8AAAD/AAAA/wAAAP8A AAD/AAAA/wAAAP8AAAD/IiIi/7Kysv/Ozs7/zc3N/8/Pz//S0tL/09PT/9PT0//S0tL/0NDQ/83N zf/Nzcz/zc3M/87OzP/Kysz/wsLD/7u7u/+wsLD/iYmJ/2NjY/9JSUn/Pj4+/0hISP9ycnL/srKy /8zMzP/MzMz/ycnJ/yEhIf8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD9 AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8JCQn/mJiY/87Ozv/MzMz/wsLC/4uLi/9U VFT/Pz8//0NDQ/9YWFj/enp6/6SkpP+4uLj/v7+//8fHy//Nzcz/zc3M/83NzP/Nzc3/z8/P/9HR 0f/T09P/09PT/9PT0//Q0ND/zc3N/87Ozv/FxcX/VlZW/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA /wAAAP8AAAD/AAAA/wAAAP8AAADxAAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP86Ojr/ 1NTU/83Nzf+0tLT/JiYm/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8GBgb/JSUi/09PgP93 d9T/kpLN/6yszv/Cwr//1tbW/9bW1v/V1dX/1NTU/9XV1f/X19f/ysrK/5OTk/8/Pz//AAAA/wAA AP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAADYAAAA/wAAAP8AAAD/AAAA /wAAAP8AAAD/AAAA/wAAAP+Li4v/0dHR/9TU1P87Ozv/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/ AAAA/wAAAP8AAAD/AAAA/wAAAP8cHL7/JSXS/ysr1f8gIGL/HR0X/z09Pf9UVFT/XV1d/1ZWVv85 OTn/FhYW/wgICP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAA AP8AAACzAAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP+ysrL/z8/P/9PT0/8AAAD/AAAA /wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8ICDX/ISHW/yAg0P8dHb3/ AQEI/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8A AAD/AAAA/wAAAP8AAAD/AAAA/wAAAOsAAACAAAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAA AP+zs7P/z8/P/9DQ0P8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA /wAAAP8BAQX/FxeS/yAg0v8gIM7/Dg5X/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/ AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAALgAAAA/AAAA/wAAAP8A AAD/AAAA/wAAAP8AAAD/AAAA/wAAAP+VlZX/0NDQ/9bW1v8XFxf/AAAA/wAAAP8AAAD/AAAA/wAA AP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/CgpA/x8fyf8gINH/GBic/wICCv8AAAD/AAAA /wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/ AAAA/wAAAHkAAAAXAAAA9AAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP9ZWVn/1dXV/9HR0f9m Zmb/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/xwc sv8gINH/ICDT/wQEG/8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA /wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAC8AAAAKAAAAuQAAAP8AAAD/AAAA/wAAAP8AAAD/ AAAA/wAAAP8bGxv/ysrK/83Nzf+zs7P/BwcH/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8A AAD/AAAA/wAAAP8AAAD/AAAA/xAQZP8hIdX/IiLa/w0NVf8AAAD/AAAA/wAAAP8AAAD/AAAA/wAA AP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA3QAAABIAAAAAAAAA dQAAAP4AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8HBwf/kJCQ/87Ozv/Jycn/TU1N/wAAAP8AAAD/ AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wYGIv8hIdn/ISHW/xUVh/8A AAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAA AP8AAAD/AAAAmAAAAAMAAAAAAAAAJwAAAO0AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/SEhI /8jIyP/Nzc3/oKCg/wsLC/8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/ AAAA/wICCv8iItv/ISHV/xgYmP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8A AAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD2AAAASwAAAAAAAAAAAAAAAAAAAKcAAAD/AAAA/wAA Av8DAxL/AwMV/wICDv8AAAD/AAAA/6Wlnf/S0s3/1tbU/1JSUv8AAAD/AAAA/wAAAP8AAAD/AAAA /wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wcHLP8hIdn/ISHW/xUVhf8AAAD/AAAA/wAAAP8AAAD/ AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAADQAAAAAAAAAAAA AAAAAAAAAAAAAA4JCTj/GBid/x0duv8dHb7/HR2//x0dvf8dHbr/Fxem/zc3of+OjtD/uLjN/9TU zP8WFhD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/xgYnP8gINL/IiLb /wsLR/8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/ AAAA/wAAAP8AAAA7AAAAAAAAAAAAAAAAAAAAAAAAAAAUFINsICDQ/yAg0f8gINH/ICDR/yAg0f8g INH/ICDR/x8f0v8bG9D/FxfQ/ycn0v80NLH/DQ1b/wYGKP8DAxT/AgIO/wICCv8BAQf/AQEH/wIC Cv8DAxb/ExN+/yAg0P8gINH/HR26/wICDv8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA /wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAKcAAAAAAAAAAAAAAAAAAAAAAAAAABISdgAQEGYH GhqowBwctv8ZGaH/GBid/xkZpf8cHLb/ICDO/yIi2/8hIdj/ICDU/x4e0P8fH9P/ISHZ/yIi3P8f H8n/Gxuw/xgYnf8XF5H/FhaQ/xgYn/8eHsT/ISHY/yAg0P8gINL/DAxN/wAAAP8AAAD/AAAA/wAA AP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA4AAAABYAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAABwcwLwMDEfUCAgv/AgIK/wICDP8CAhD/AwMV/wcHLf8PD1// ISGg/yEhz/8YGND/GxvQ/x4e0f8gINH/ICDR/yAg0f8gINL/ICDS/yAg0f8gINH/ISHU/yEh1v8M DEr/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAA AP8AAAD6AAAAVQAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFsAAAD/AAAA /wAAAP8AAAD/AAAA/wAAAP8AAAD/AgIA/7Cwpv+3t87/i4vP/0xMu/8YGKz/HR28/x4ewP8eHsL/ Hh7C/x4ewP8cHLj/FBSA/wMDD/8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8A AAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAACQAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAABoAAAA/QAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/yQkJP/S0s//09PN /83Nxf8UFAr/AAAD/wQEGP8FBSL/BgYi/wQEGP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/ AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAI4AAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAZgAAAP8AAAD/AAAA/wAA AP8AAAD/AAAA/wAAAP9qamr/1dXV/87Ozv+RkZH/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA /wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/ AAAAjAAAAAUAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAFkAAAD0AAAA/wAAAP8AAAD/AAAA/wAAAP8ODg7/ubm5/83Nzf/BwcH/Jycn/wAA AP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA /wAAAP8AAAD/AAAA/wAAAPgAAACHAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAtAAAAvgAAAP8AAAD/AAAA/wAAAP8B AQH/bW1t/83Nzf/MzMz/ZmZm/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAA AP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA1QAAAEoAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAABgAAAGgAAAD/AAAA/wAAAP8AAAD/LS0t/8HBwf/Nzc3/mZmZ/woKCv8AAAD/AAAA/wAAAP8A AAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAACLAAAADgAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAALAAAAoQAAAOwAAAD+AAAA/7S0tP/Nzc3/ vr6+/xISEv8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8A AADxAAAAugAAAB8AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAACQAAABxAAAAtpWVlfHNzc3/0tLS/xcXF/8AAAD/AAAA/wAAAP8AAAD/AAAA/wAAAP8AAAD/ AAAA/wAAAP8AAAD7AAAAwQAAAH8AAAAzAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACYyMjBaurq48ycnJfhMTE7AAAADVAAAA 7wAAAPwAAAD+AAAA8wAAANsAAAC4AAAAhwAAAEgAAAAZAAAADAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAD//wAA//8AAP/8AAA/ /wAA//AAAA//AAD/wAAAA/8AAP+AAAAB/wAA/wAAAAD/AAD+AAAAAD8AAPwAAAAAPwAA+AAAAAAf AADwAAAAAA8AAOAAAAAABwAA4AAAAAAHAADAAAAAAAMAAMAAAAAAAwAAgAAAAAABAACAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA AAAAAAAAAAAAAAAAAAAAgAAAAAAAAACAAAAAAAEAAMAAAAAAAwAAwAAAAAADAADgAAAAAAcAAOAA AAAABwAA8AAAAAAPAAD4AAAAAB8AAPwAAAAAPwAA/gAAAAA/AAD/AAAAAP8AAP+AAAAB/wAA/8AA AAP/AAD/8AAAD/8AAP/8AAA//wAA//8AAP//AAA=">
</head>
<body role="document" onload="
    res = {{ json }};
    offline_percents = {{ percents }};
    d3.boxplot.launch(res);
    $('#summary-offline').on('click', function() {dgenies.result.summary.show(offline_percents)});
">

    <div id="main-wrapper">
        <!-- Fixed navbar -->

        <div id="main-error">

        </div>

        <div class="container theme-showcase" id="body-container" role="main">

            

            

<div id="supdraw">
    <div class="top-forms">
        <a href="http://dgenies.toulouse.inra.fr" target="_blank"><img class="logo-stick" alt="D-Genies" src="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAHMAAAAeCAYAAAAfKSFiAAAABmJLR0QA/wD/AP+gvaeTAAAACXBI WXMAAA3XAAAN1wFCKJt4AAAAB3RJTUUH4gcNDTgZrD6TjAAADYtJREFUaN7tW3lQlNeW/93vA7tB CNK0CBrAdgtGnhqFmNE3LiQupATHslKV+GJcUhmpxCVuaGYcNVM+y0RT5ZtYWSxetJJYWmpMLB1D FgKYhJAQQR+KsURlbaDbZhFl7f5+84fdN91AN83L5K9wq04B5zv33OV3zz3n3HsB/CvjkpOTX/jq q69OnDp1qh6AHQDdSAPgcP7Uun0boN5JE0K4yOGcUxeZAXwOYCOAfwEwzB+QAvr4nghgJ4AFDocj 4KGHHkJ5eXlvcsJJruLqsIKB0r245gYAFJJQFEWQdJeJdtIC599WAH8DcBzAzf405gJgi/tKWrZs GcvKyjhp0qT+rD7HgAV6UJdr5xJCUAhB1+9+1m8F8GJ/wBQArrsrMRgMzMvLY15e3j+1nQyACALo 7I3vDmo/5vJ/+9r1XB9ruivZsHUrb1ssnJOWxkEAHw4M5LCAgAFQ/R+3ozcQAVARggKgAlA4yU+9 WW7G5/mLs5QBGO3O+LPRiMyNG9FSWIh7xcXQkRL1Vk3DyZYWvN/UBM0/XyH+gD7SAUB1n3BFUeDQ NAgh4PKVwt2RCgHN04d6K18CmN8DzL8OHfrfMQEB/3WjsxNGVUWiXo+4gAC0dnXhPolWAK1CoJNE lxPQwYqCMYMG4aO7d7HdavWnce2PFBQpgB1CBGgkVPFgqh3+gQTFOVl+lO0A/uoO5sy/R0Xl/Umn g04IdJFo1jSocXEwTJmC76qqcOCzz1ArBO5rmmzEqKrYaTTi30JC8ExNDQra2/2N5v4IFkpFCKGR HlbnskZFUR5YpRNc9pIOqEL4A347gBkAilzmmTVYUWhUVQ5TVUaqKuPCw5l9/jxvl5cTqup1707U 6/ljXBz3RUYO+E8nPfzww9y/fz9fe+21XgMeRVF81u9HQOSiA64dL6E3B71gwQJWVlZy1qxZPhVN 0umYHxfH//l/APPs2bPMzc3lN998w+zsbB4+fJgzZ85kZP90EwCHDRvGFStWsKqqiq7S2dnJ3bt3 MyIi4ncDUgjB7du3a6423VM51WkUfYLZ7acfZAUQCQDpvQkUFxfz/PnzNBgMPhUtDAnhNZOJS0JD fxOYQgh6K9XV1ZwzZ47f+tPT02mz2bzqe/311/+Z1e83mOnp6VpbWxtzc3Op0+n6ZZXulin61/Yi OI+NPD7Ex8fzxo0b3LFjh08FOiF4dPhwlo8axTA/OukLzCVLlsjJXr58OWfPns3z589LXkFBQZ8L CwBfffVV2u12WW/r1q2Mj49nfHw8ly5dyqqqKkZFRf3eW609NDSUQUFBPazSn0XkSlGU/i24LABo 6v5h5syZLC0t5dq1a30qeFyvZ4XJxN3OSf4tq/2LL74gSXZ0dHDUqFGSf+HCBQnM448/7lPHhAkT WFdXR5JsbGzklClT/Gp72rRp/OSTT9jY2MjW1lbm5eVxxowZHkAcO3aMubm5jI+P57p162g2m9nS 0sJdu3Z56IqKimJpaalWUlLCqVOnSn5AQABTUlKYk5PD+/fvs7m5mSdPnmRMTIyUCQkJ4ZtvvsmK igp2dnayqqqKmZmZNJlM/oyjDL1ZSVxcHG/fvs2DBw96t0qA344cyeIFC/jKypVct349t23bxs2b N3PVqlV+WZE7VVRUkCS//vprhrpt2WvXrpVgzp8/36eO9evXS9k1a9b02aaqqlyzZo2sU1ZWxsbG RrkYoqOjCYDjx4+nzWZjR0cHDx8+3GPbfu6556TO1atXS3/pskZVVXno0CEp//PPP9NqtZIk7927 J+v+8MMPUubGjRvs6OggSS5ZssSfkyIHvH08cOAAS0tLeejQIc6ePZsmk4mJiYlcuXIl9+3fz8+O HeOlnBxeLChgyZUrLCsrY3l5OW/dusWSkhLm5ORw7NixfgE5cuRIaVHdF9AzzzwjB5iWluZTz6VL l6Ssi2cymThu3DhJY8aMoV6vJwCOGTNGyp87d456vZ6qqkrevHnzCIArVqygw+EgSVZVVXH69Okc P368lLt48aJs7+TJkyRJi8UiJ/+tt96Ssi+++CLDwsI8xhUVFcWkpCS2tbWRJHfs2MEhQ4ZwxIgR XLRoEYODg/06+vN6a5KRkQGj0YipU6fiySefhKqq0DQNHR0daL13D6K9HXcbGvCP0lLcunkTRUVF qKqqwuDBg5GWloann34aWVlZeOSRR2C3230mSqNHj0ZwcDBIora21uPbo48+Kn+3WCwAgIiICGja ryl1S0sL7HY7Jk2aBADIzs6W327duuWhr66uDhMnTkR7ezs+/fRTAEBXVxcWLlyIoKAgZGRkSFnX DVFsbKzMCw8dOoT8/HwEBwejoaEBBoMBDQ0Nsk5SUhIA4JdffgFJGI1GJCcnAwB++uknHD9+HIGB gZg8ebJH/wcNGgThPFiYN28ePvroI1RWVuLcuXMyL9U07df81MepjFe009LSuGHDBm7bto0bN27k K+npPLtoEW9PmsQ/+wh6li5dyitXrvDll1/u0zJXr15Nh8PBjo4OLlu2zONbTk4OSbKtrY0JCQmM jY1lbW0tS0tLWVpayqKiIiYkJDAiIkKu9IyMjAc5cGIiKyoqaDab2dnZSZL89ttvCYDBwcFS/vbt 2zx16hQvX74seR988AF1Oh31ej3PnDlDkrxz5460jPDwcCm7atUq2V9X2blzJwEwOTlZ8sxmM0+d OsXr169L3qZNmx5EuUIwKytL8hsaGrhnz54e0bB7MNXbNtvkb8gNgDGKwmqTiRl9+MSJEyfyu+++ 4549e/rUvXv3bpJkU1MTx40b5+G7KysrJQiBgYHMzMz08Fc2m41jx45ldHS05LmCEp1Ox6FDh3La tGnSR7333nsPxhETQ5LUNOniePfuXR49epRz586VkxgWFsabN29Kf+7q2/Lly2U919wsXrxY8lJT UwmAL7zwQg8fW1tby7ffflsGaK76g4ODuWnTJg/Z7du3yzb7SGvKek1NfNE3sbG8ajIxLjDQp9zc uXNZXFzMDRs2+ExNQkNDZcRaXV3tce324YcfykHt3btX+sCxY8dKio2NlYN0nyz39qZMmSJBe+ml l+RC6S2x705Go5FdXV0k6bEwXX22WCySd+LECWnBLp2rV6+W7YSEhHhNRVy3JwA4ffp03rt3jyR5 5MgRBjrnug/LzAKAf/cXyCGKwusmE/dHRlL14YhVVeWuXbtYU1PD8ePH+wQzOjpa5oXXrl3js88+ y61bt/LixYtyErKzs/3q39mzZ2Wdd955h6mpqVy4cCH37dsn+a60Z8iQIZJ3+vRpxsTEMCoqiomJ idy4caO0TPdA54knnpBtuaLe48ePS15+fj5J8scff2RYWBgBMDU1VdY/cuQIhw8fzhEjRnDOnDlM S0ujqqqMjIzk888/z9GjRzM8PJxJSUlS//vvv98jR/USBC3yepzXGz2m1/OaycRVzo56I71ez0uX LnkM1BuYjz32mBysw+GQVuAOiiua64tmzZrlUbetrY2tra0yEnWPcruDb7VaabFY2NTUxIaGBtnm G2+80aNuYGCg5G3ZskX60JKSEpLkmTNn5BhDQkJYVFREkrTb7bKd9vZ2njhxgvrAQE6YMIFtbW20 2Wysq6tjc3Oz3Elc/ljef/a+1crjPDhNtM/JmqjT8ReTia+Eh/uU+9vBg7x+9SoT4+M9Du/DFIVq NzBTUlJos9lYWVnJyspKVlRUsLq6mkePHuXkyZP7ffiQkJDAq1evsr6+njabjVarlWazmYWFhVy8 eLFnKB8QwI8//ph1dXW02Wysr6+n2Wz2OCA3m82sqalhbm6u5CUlJbG2tpZ37tzhU089JQ8sioqK WFlZyXfffddjjFFRUSwoKKDFYpGAXblyhampqRRCcPjw4czPz2d9fT3v3LlDi8VCs9nMlJSUHv7S y6nQAQCK69blXwFc6OuuJVAI/GPkSJjtdmy2WlHsduUVpCgwCoHkUaPwH3/5C5ovXULj5csYomnQ CwE7iTqHA+vq63mzq+t3vwILDw+H0WhEW1sbampqfIbzISEhiI6ORnNzs0x/3K+rfsPDLY9xGgwG REREwGq1oqmpSbbhugYLNxhgMBjQ0tICS339r/1wpiUuWbpdZgugA0Ikk8x3b+x1ADv66uFUvR5n RoxARVcXGjQNGglFCAwSAsEAgoXAoM5OPBQUhPsACtrbUd7VhQhFgU4IptfX/5FeG9j9eAHpcd/p z6W1cN5zqg9eJOwjkOHXs5HeyoygIGwxGDAsIODBjTiJLgAiNhYR06fjTFkZdp4+jc6BZyM9no14 Bcm5C7AbuK6DBEUIaJrWHfQvAcwXgGC39eD1QZc3ekhRGBMQwHBFYWB4OLMLC/l5To63gGfgQZcf pABUu92aeAl6Pvfyjsv3U0t/aO/evayoqPAI3weeWvb91NInsD1B9PupZXcL3dyfhgsLC5mZmdk9 jRh4BN3tntPfxa0oSm8H6z4fQStezmoBYD+AJADnnJ3wWiZMmIDQ0FAUFxejtbUVbqto4N8TPIvq Nsd9Pr5zi6StAP4TwJ8A/N2bfF+R1s8AUgGMw4N/YEkBMAvAUHenHhMTwwsXLuD7779336rFAHZe 3ZjotnV2DxLrNE0rA5CnKMqXDoejDEB9X4r/D7aT/teRx+DCAAAAAElFTkSuQmCC"/></a>
        <form id="select-zone">
            <div class="chosen-widget">
                <select id="select-target" data-placeholder="Select a target...">
                    <option value="###NONE###" label=" "></option>
                </select>
            </div>
            <div class="chosen-widget">
                <select id="select-contig" data-placeholder="Select a query...">
                    <option value="###NONE###" label=" "></option>
                </select>
            </div>
            <input type="button" class="submit" value="Apply"/>
        </form>
    </div>
    <div class="master">
        <div id="draw"></div>
        <div id="sidebar">
            <div id="legend">
                <div class="title">
                    Legend
                </div>
                <div class="draw"></div>
            </div>
            <form id="form-parameters">
                <p><label>Filter small matches:<br/>
                <input type="range" min="0" max="6" value="0" step="1" id="filter_size"/></label></p>
                <p><label>Min identity (abs):<br/>
                <input type="number" min="0" max="0.95" value="0" step="0.05" id="filter_identity"/></label></p>
                <p><label class="input-checkbox-label"><input type="checkbox" id="stroke-linecap"/> Strong precision</label></p>
                <p><label>Stroke width:<br/>
                <input type="range" min="0" max="3" value="1" step="1" id="stroke-width"/></label></p>
                <p><label>Regions delimiters:<br/>
                <input type="range" min="0" max="5" value="2" step="1" id="chroms-limits"/></label></p>
                <p><input type="button" id="summary-offline" value="Summary"/></p>
            </form>
        </div>
    </div>
    <div id="loading">
        <div class="cssload-container">
            <div class="cssload-whirlpool"></div>
        </div>
        <div class="label">
            <div class="mylabel">
                Loading...
            </div>
        </div>
    </div>
    <div id="export-pict" style="display: none;"></div>
    <div id="modal-stats" style="display: none;">
        <div id="draw-stats" style="margin-top: 15px"></div>
    </div>
</div>

<div style="position:relative;width:90%;padding:10px 5px 0 5px;background-color:white;border:1px solid lightgrey;border-radius:5px; margin-top: 15px;">
    <span class="label label-primary" style="position:absolute;top:-10px;left:-10px">How to cite</span>
    <span style="font-weight: bold; font-size: 0.9em;">Cabanettes F, Klopp C. (2018) D-GENIES: dot plot large genomes in an interactive, efficient and simple way. PeerJ 6:e4958 <a href="https://doi.org/10.7717/peerj.4958">https://doi.org/10.7717/peerj.4958</a></span>
</div>


            <footer>

                <hr>
                <div class="container" style="text-align: center;">
                    <p>Copyright © 2017, INRA | Designed by <a target="_blank" href="http://bioinfo.genotoul.fr/">GenoToul
                        Bioinfo platform</a>.</p>
                </div>
            </footer>

        </div> <!-- /container -->
    </div>

<script type="text/javascript">
            var supportsTemplateLiterals = false;
            try {
                eval("`foo`");
                supportsTemplateLiterals = true;
            }
            catch (e) {
            }
            if (!supportsTemplateLiterals) {
                $("#main-error").html("<span class='big'>Your browser is not supported!</span><br/>Please use a compatible browser like <a href=\"https://www.mozilla.org/firefox\">Firefox</a> or <a href=\"https://www.google.com/chrome/\">Google Chrome / Chromium</a>").show();
            }
        </script>
</body>
</html>
