{% extends 'base.html' %}
{% block scripts %}
    {{ super() }}
    <style>
        em {
            color: red;
            font-weight: bold;
        }
        #body-container {
            background: url("{{ url_for('static', filename='images/contact.svg') }}") no-repeat 0 30px;
            background-size: 200px 200px;
        }
        h1 {
            margin-bottom: 50px !important;
        }
    </style>
{% endblock %}
{% block content %}

    <h1>Contact us</h1>

    <h2>User support</h2>

    <p>Please send a mail to <a href="mailto:support.bioinfo.genotoul@inrae.fr?subject=[dgenies-support] ">support.bioinfo.genotoul@inrae.fr</a>.</p>
    <p><em>Important:</em> please keep <strong>[dgenies-support]</strong> tag at the beginning of the subject of the mail. Otherwise, the response delay will be increased.</p>

    <h2>Developer support</h2>

    <p>For any development support, including:</p>

        <ul>
            <li>Bug report</li>
            <li>Feature request</li>
            <li>...</li>
        </ul>
    <p>please submit an issue to our <a href="https://github.com/genotoul-bioinfo/dgenies/issues" target="_blank">github repository</a>.</p>

{% endblock %}